kiali-client-python
=========================

This repository includes the necessary Python client libraries to access Kiali remotely

# Introduction

Python client to access Kiali (Service Mesh Observability), an abstraction to invoke REST-methods on the server endpoint using urllib2. No external dependencies, works with Python 2.7.x (tested on 2.7.14) and Python 3.6.x (tested with Python 3.6.8, might work with newer versions also).

## License and copyright

```
   Copyright 2018 Red Hat, Inc. and/or its affiliates
   and other contributors.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
```

## Installation

To install, run ``python setup.py install`` if you installed from source code, or ``pip install kiali-client`` if using pip.


## General Usage
To instiante a Kiali Client, use KialiClient() method. It requires the `host`, `username` and `password` parameters

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
```

Another parameters possible to use with Client
* host (default: `localhost`)
* scheme (default: `http`, options: `https` and `http`)
* port(default: `80`)
* username(default:`admin`)
* password(default:`admin`)


```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> namespaces = client.namespace_list()
```

# Methods Available

## Api Status

- This method will return a dictionary of status

Usage Example:
```python
from kiali import KialiClient
client = KialiClient(host='kiali-url.com')
client.status()
{'status': {'Kiali console version': '0.2.10-SNAPSHOT.653', 'Kiali core commit hash': '3d8f22fe278e184f3682e88f3487623db950a07d', 'Kiali core version': '0.0.1.Final-SNAPSHOT', 'Kiali state': 'running'}, 'products': [{'name': 'Istio', 'version': '0.7.1'}, {'name': 'Prometheus', 'version': '2.0.0'}, {'name': 'Kubernetes', 'version': 'v1.7.6+a08f5eeb62'}]}
```

## Namespace List
- This method will return a list of Namespace

- No Required Parameters

Usage Example:
```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.namespace_list()
[{'name': 'bookinfo'}, {'name': 'default'}, {'name': 'istio-system'}, {'name': 'kiali-test-box'}, {'name': 'kiali-test-breadth-sink'}, {'name': 'kiali-test-breath'}, {'name': 'kiali-test-circle'}, {'name': 'kiali-test-circle-callback'}, {'name': 'kiali-test-depth'}, {'name': 'kiali-test-depth-sink'}, {'name': 'kiali-test-hourglass'}, {'name': 'kube-public'}, {'name': 'kube-system'}, {'name': 'logging'}, {'name': 'management-infra'}, {'name': 'openshift'}, {'name': 'openshift-infra'}, {'name': 'openshift-node'}, {'name': 'samples'}]
```

## Namespace Metrics

- This method will return a metrics of a namespace
- Required Parameter (`namespace`)

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.namespace_metrics("bookinfo")
{'metrics': {'request_count_in': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '3.673'], [1527161452.257, '3.673'], [1527161467.257, '3.636'], [1527161482.257, '3.636'], [1527161497.257, '3.673'], [1527161512.257, '3.618'], [1527161527.257, '3.636'], [1527161542.257, '3.673'], [1527161557.257, '3.636'], [1527161572.257, '3.655'], [1527161587.257, '3.673'], [1527161602.257, '3.636'], [1527161617.257, '3.691'], [1527161632.257, '3.709'], [1527161647.257, '3.709'], [1527161662.257, '3.673'], [1527161677.257, '3.618'], [1527161692.257, '3.655'], [1527161707.257, '3.618'], [1527161722.257, '3.636'], [1527161737.257, '3.691'], [1527161752.257, '3.673'], [1527161767.257, '3.655'], [1527161782.257, '3.636'], [1527161797.257, '3.618'], [1527161812.257, '3.655'], [1527161827.257, '3.727'], [1527161842.257, '3.691'], [1527161857.257, '3.709'], [1527161872.257, '3.655'], [1527161887.257, '3.691'], [1527161902.257, '3.673'], [1527161917.257, '3.673'], [1527161932.257, '3.636'], [1527161947.257, '3.673'], [1527161962.257, '3.673'], [1527161977.257, '3.655'], [1527161992.257, '3.655'], [1527162007.257, '3.673'], [1527162022.257, '3.673'], [1527162037.257, '3.655'], [1527162052.257, '3.673'], [1527162067.257, '3.691'], [1527162082.257, '3.673'], [1527162097.257, '3.691'], [1527162112.257, '3.709'], [1527162127.257, '3.618'], [1527162142.257, '3.655'], [1527162157.257, '3.655'], [1527162172.257, '3.673'], [1527162187.257, '3.655'], [1527162202.257, '3.636'], [1527162217.257, '3.673'], [1527162232.257, '3.636'], [1527162247.257, '3.636'], [1527162262.257, '3.709'], [1527162277.257, '3.691'], [1527162292.257, '3.636'], [1527162307.257, '3.636'], [1527162322.257, '3.6'], [1527162337.257, '3.709'], [1527162352.257, '3.673'], [1527162367.257, '3.673'], [1527162382.257, '3.727'], [1527162397.257, '3.618'], [1527162412.257, '3.655'], [1527162427.257, '3.745'], [1527162442.257, '3.673'], [1527162457.257, '3.709'], [1527162472.257, '3.764'], [1527162487.257, '3.709'], [1527162502.257, '3.673'], [1527162517.257, '3.655'], [1527162532.257, '3.636'], [1527162547.257, '3.618'], [1527162562.257, '3.655'], [1527162577.257, '3.691'], [1527162592.257, '3.636'], [1527162607.257, '3.727'], [1527162622.257, '3.727'], [1527162637.257, '3.636'], [1527162652.257, '3.727'], [1527162667.257, '3.618'], [1527162682.257, '3.655'], [1527162697.257, '3.673'], [1527162712.257, '3.691'], [1527162727.257, '3.673'], [1527162742.257, '3.673'], [1527162757.257, '3.655'], [1527162772.257, '3.655'], [1527162787.257, '3.655'], [1527162802.257, '3.673'], [1527162817.257, '3.655'], [1527162832.257, '3.655'], [1527162847.257, '3.673'], [1527162862.257, '3.691'], [1527162877.257, '3.673'], [1527162892.257, '3.691'], [1527162907.257, '3.709'], [1527162922.257, '3.673'], [1527162937.257, '3.636'], [1527162952.257, '3.673'], [1527162967.257, '3.673'], [1527162982.257, '3.691'], [1527162997.257, '3.727'], [1527163012.257, '3.636'], [1527163027.257, '3.673'], [1527163042.257, '3.673'], [1527163057.257, '3.636'], [1527163072.257, '3.673'], [1527163087.257, '3.691'], [1527163102.257, '3.673'], [1527163117.257, '3.636'], [1527163132.257, '3.673'], [1527163147.257, '3.673'], [1527163162.257, '3.636'], [1527163177.257, '3.673'], [1527163192.257, '3.673'], [1527163207.257, '3.636'], [1527163222.257, '3.673'], [1527163237.257, '3.636']]}]}, 'request_count_out': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '2.673'], [1527161452.257, '2.673'], [1527161467.257, '2.655'], [1527161482.257, '2.636'], [1527161497.257, '2.655'], [1527161512.257, '2.636'], [1527161527.257, '2.636'], [1527161542.257, '2.673'], [1527161557.257, '2.655'], [1527161572.257, '2.655'], [1527161587.257, '2.673'], [1527161602.257, '2.655'], [1527161617.257, '2.691'], [1527161632.257, '2.691'], [1527161647.257, '2.691'], [1527161662.257, '2.673'], [1527161677.257, '2.636'], [1527161692.257, '2.655'], [1527161707.257, '2.636'], [1527161722.257, '2.655'], [1527161737.257, '2.691'], [1527161752.257, '2.655'], [1527161767.257, '2.636'], [1527161782.257, '2.636'], [1527161797.257, '2.618'], [1527161812.257, '2.655'], [1527161827.257, '2.727'], [1527161842.257, '2.691'], [1527161857.257, '2.691'], [1527161872.257, '2.673'], [1527161887.257, '2.673'], [1527161902.257, '2.673'], [1527161917.257, '2.673'], [1527161932.257, '2.655'], [1527161947.257, '2.673'], [1527161962.257, '2.655'], [1527161977.257, '2.655'], [1527161992.257, '2.655'], [1527162007.257, '2.673'], [1527162022.257, '2.655'], [1527162037.257, '2.655'], [1527162052.257, '2.673'], [1527162067.257, '2.691'], [1527162082.257, '2.655'], [1527162097.257, '2.691'], [1527162112.257, '2.709'], [1527162127.257, '2.618'], [1527162142.257, '2.655'], [1527162157.257, '2.655'], [1527162172.257, '2.655'], [1527162187.257, '2.673'], [1527162202.257, '2.636'], [1527162217.257, '2.655'], [1527162232.257, '2.655'], [1527162247.257, '2.636'], [1527162262.257, '2.691'], [1527162277.257, '2.673'], [1527162292.257, '2.655'], [1527162307.257, '2.636'], [1527162322.257, '2.6'], [1527162337.257, '2.691'], [1527162352.257, '2.673'], [1527162367.257, '2.673'], [1527162382.257, '2.709'], [1527162397.257, '2.636'], [1527162412.257, '2.655'], [1527162427.257, '2.727'], [1527162442.257, '2.691'], [1527162457.257, '2.709'], [1527162472.257, '2.745'], [1527162487.257, '2.709'], [1527162502.257, '2.673'], [1527162517.257, '2.655'], [1527162532.257, '2.655'], [1527162547.257, '2.618'], [1527162562.257, '2.655'], [1527162577.257, '2.673'], [1527162592.257, '2.655'], [1527162607.257, '2.709'], [1527162622.257, '2.709'], [1527162637.257, '2.655'], [1527162652.257, '2.709'], [1527162667.257, '2.636'], [1527162682.257, '2.673'], [1527162697.257, '2.655'], [1527162712.257, '2.691'], [1527162727.257, '2.691'], [1527162742.257, '2.673'], [1527162757.257, '2.655'], [1527162772.257, '2.673'], [1527162787.257, '2.655'], [1527162802.257, '2.673'], [1527162817.257, '2.655'], [1527162832.257, '2.655'], [1527162847.257, '2.673'], [1527162862.257, '2.691'], [1527162877.257, '2.673'], [1527162892.257, '2.691'], [1527162907.257, '2.691'], [1527162922.257, '2.673'], [1527162937.257, '2.636'], [1527162952.257, '2.673'], [1527162967.257, '2.655'], [1527162982.257, '2.691'], [1527162997.257, '2.709'], [1527163012.257, '2.655'], [1527163027.257, '2.673'], [1527163042.257, '2.655'], [1527163057.257, '2.636'], [1527163072.257, '2.673'], [1527163087.257, '2.691'], [1527163102.257, '2.673'], [1527163117.257, '2.636'], [1527163132.257, '2.673'], [1527163147.257, '2.691'], [1527163162.257, '2.655'], [1527163177.257, '2.673'], [1527163192.257, '2.655'], [1527163207.257, '2.636'], [1527163222.257, '2.655'], [1527163237.257, '2.636']]}]}, 'request_error_count_in': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0'], [1527161452.257, '0'], [1527161467.257, '0'], [1527161482.257, '0'], [1527161497.257, '0'], [1527161512.257, '0'], [1527161527.257, '0'], [1527161542.257, '0'], [1527161557.257, '0'], [1527161572.257, '0'], [1527161587.257, '0'], [1527161602.257, '0'], [1527161617.257, '0'], [1527161632.257, '0'], [1527161647.257, '0'], [1527161662.257, '0'], [1527161677.257, '0'], [1527161692.257, '0'], [1527161707.257, '0'], [1527161722.257, '0'], [1527161737.257, '0'], [1527161752.257, '0'], [1527161767.257, '0'], [1527161782.257, '0'], [1527161797.257, '0'], [1527161812.257, '0'], [1527161827.257, '0'], [1527161842.257, '0'], [1527161857.257, '0'], [1527161872.257, '0'], [1527161887.257, '0'], [1527161902.257, '0'], [1527161917.257, '0'], [1527161932.257, '0'], [1527161947.257, '0'], [1527161962.257, '0'], [1527161977.257, '0'], [1527161992.257, '0'], [1527162007.257, '0'], [1527162022.257, '0'], [1527162037.257, '0'], [1527162052.257, '0'], [1527162067.257, '0'], [1527162082.257, '0'], [1527162097.257, '0'], [1527162112.257, '0'], [1527162127.257, '0'], [1527162142.257, '0'], [1527162157.257, '0'], [1527162172.257, '0'], [1527162187.257, '0'], [1527162202.257, '0'], [1527162217.257, '0'], [1527162232.257, '0'], [1527162247.257, '0'], [1527162262.257, '0'], [1527162277.257, '0'], [1527162292.257, '0'], [1527162307.257, '0'], [1527162322.257, '0'], [1527162337.257, '0'], [1527162352.257, '0'], [1527162367.257, '0'], [1527162382.257, '0'], [1527162397.257, '0'], [1527162412.257, '0'], [1527162427.257, '0'], [1527162442.257, '0'], [1527162457.257, '0'], [1527162472.257, '0'], [1527162487.257, '0'], [1527162502.257, '0'], [1527162517.257, '0'], [1527162532.257, '0'], [1527162547.257, '0'], [1527162562.257, '0'], [1527162577.257, '0'], [1527162592.257, '0'], [1527162607.257, '0'], [1527162622.257, '0'], [1527162637.257, '0'], [1527162652.257, '0'], [1527162667.257, '0'], [1527162682.257, '0'], [1527162697.257, '0'], [1527162712.257, '0'], [1527162727.257, '0'], [1527162742.257, '0'], [1527162757.257, '0'], [1527162772.257, '0'], [1527162787.257, '0'], [1527162802.257, '0'], [1527162817.257, '0'], [1527162832.257, '0'], [1527162847.257, '0'], [1527162862.257, '0'], [1527162877.257, '0'], [1527162892.257, '0'], [1527162907.257, '0'], [1527162922.257, '0'], [1527162937.257, '0'], [1527162952.257, '0'], [1527162967.257, '0'], [1527162982.257, '0'], [1527162997.257, '0'], [1527163012.257, '0'], [1527163027.257, '0'], [1527163042.257, '0'], [1527163057.257, '0'], [1527163072.257, '0'], [1527163087.257, '0'], [1527163102.257, '0'], [1527163117.257, '0'], [1527163132.257, '0'], [1527163147.257, '0'], [1527163162.257, '0'], [1527163177.257, '0'], [1527163192.257, '0'], [1527163207.257, '0'], [1527163222.257, '0'], [1527163237.257, '0']]}]}, 'request_error_count_out': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0'], [1527161452.257, '0'], [1527161467.257, '0'], [1527161482.257, '0'], [1527161497.257, '0'], [1527161512.257, '0'], [1527161527.257, '0'], [1527161542.257, '0'], [1527161557.257, '0'], [1527161572.257, '0'], [1527161587.257, '0'], [1527161602.257, '0'], [1527161617.257, '0'], [1527161632.257, '0'], [1527161647.257, '0'], [1527161662.257, '0'], [1527161677.257, '0'], [1527161692.257, '0'], [1527161707.257, '0'], [1527161722.257, '0'], [1527161737.257, '0'], [1527161752.257, '0'], [1527161767.257, '0'], [1527161782.257, '0'], [1527161797.257, '0'], [1527161812.257, '0'], [1527161827.257, '0'], [1527161842.257, '0'], [1527161857.257, '0'], [1527161872.257, '0'], [1527161887.257, '0'], [1527161902.257, '0'], [1527161917.257, '0'], [1527161932.257, '0'], [1527161947.257, '0'], [1527161962.257, '0'], [1527161977.257, '0'], [1527161992.257, '0'], [1527162007.257, '0'], [1527162022.257, '0'], [1527162037.257, '0'], [1527162052.257, '0'], [1527162067.257, '0'], [1527162082.257, '0'], [1527162097.257, '0'], [1527162112.257, '0'], [1527162127.257, '0'], [1527162142.257, '0'], [1527162157.257, '0'], [1527162172.257, '0'], [1527162187.257, '0'], [1527162202.257, '0'], [1527162217.257, '0'], [1527162232.257, '0'], [1527162247.257, '0'], [1527162262.257, '0'], [1527162277.257, '0'], [1527162292.257, '0'], [1527162307.257, '0'], [1527162322.257, '0'], [1527162337.257, '0'], [1527162352.257, '0'], [1527162367.257, '0'], [1527162382.257, '0'], [1527162397.257, '0'], [1527162412.257, '0'], [1527162427.257, '0'], [1527162442.257, '0'], [1527162457.257, '0'], [1527162472.257, '0'], [1527162487.257, '0'], [1527162502.257, '0'], [1527162517.257, '0'], [1527162532.257, '0'], [1527162547.257, '0'], [1527162562.257, '0'], [1527162577.257, '0'], [1527162592.257, '0'], [1527162607.257, '0'], [1527162622.257, '0'], [1527162637.257, '0'], [1527162652.257, '0'], [1527162667.257, '0'], [1527162682.257, '0'], [1527162697.257, '0'], [1527162712.257, '0'], [1527162727.257, '0'], [1527162742.257, '0'], [1527162757.257, '0'], [1527162772.257, '0'], [1527162787.257, '0'], [1527162802.257, '0'], [1527162817.257, '0'], [1527162832.257, '0'], [1527162847.257, '0'], [1527162862.257, '0'], [1527162877.257, '0'], [1527162892.257, '0'], [1527162907.257, '0'], [1527162922.257, '0'], [1527162937.257, '0'], [1527162952.257, '0'], [1527162967.257, '0'], [1527162982.257, '0'], [1527162997.257, '0'], [1527163012.257, '0'], [1527163027.257, '0'], [1527163042.257, '0'], [1527163057.257, '0'], [1527163072.257, '0'], [1527163087.257, '0'], [1527163102.257, '0'], [1527163117.257, '0'], [1527163132.257, '0'], [1527163147.257, '0'], [1527163162.257, '0'], [1527163177.257, '0'], [1527163192.257, '0'], [1527163207.257, '0'], [1527163222.257, '0'], [1527163237.257, '0']]}]}}, 'histograms': {'request_duration_in': {'average': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.021'], [1527161452.257, '0.021'], [1527161467.257, '0.021'], [1527161482.257, '0.021'], [1527161497.257, '0.021'], [1527161512.257, '0.021'], [1527161527.257, '0.022'], [1527161542.257, '0.022'], [1527161557.257, '0.021'], [1527161572.257, '0.022'], [1527161587.257, '0.022'], [1527161602.257, '0.022'], [1527161617.257, '0.021'], [1527161632.257, '0.021'], [1527161647.257, '0.02'], [1527161662.257, '0.019'], [1527161677.257, '0.019'], [1527161692.257, '0.019'], [1527161707.257, '0.019'], [1527161722.257, '0.019'], [1527161737.257, '0.02'], [1527161752.257, '0.021'], [1527161767.257, '0.02'], [1527161782.257, '0.021'], [1527161797.257, '0.02'], [1527161812.257, '0.02'], [1527161827.257, '0.02'], [1527161842.257, '0.019'], [1527161857.257, '0.019'], [1527161872.257, '0.018'], [1527161887.257, '0.018'], [1527161902.257, '0.019'], [1527161917.257, '0.018'], [1527161932.257, '0.019'], [1527161947.257, '0.02'], [1527161962.257, '0.02'], [1527161977.257, '0.02'], [1527161992.257, '0.019'], [1527162007.257, '0.019'], [1527162022.257, '0.019'], [1527162037.257, '0.019'], [1527162052.257, '0.019'], [1527162067.257, '0.019'], [1527162082.257, '0.02'], [1527162097.257, '0.019'], [1527162112.257, '0.02'], [1527162127.257, '0.02'], [1527162142.257, '0.02'], [1527162157.257, '0.019'], [1527162172.257, '0.019'], [1527162187.257, '0.019'], [1527162202.257, '0.019'], [1527162217.257, '0.019'], [1527162232.257, '0.018'], [1527162247.257, '0.018'], [1527162262.257, '0.018'], [1527162277.257, '0.019'], [1527162292.257, '0.019'], [1527162307.257, '0.019'], [1527162322.257, '0.02'], [1527162337.257, '0.02'], [1527162352.257, '0.02'], [1527162367.257, '0.02'], [1527162382.257, '0.02'], [1527162397.257, '0.019'], [1527162412.257, '0.019'], [1527162427.257, '0.019'], [1527162442.257, '0.019'], [1527162457.257, '0.019'], [1527162472.257, '0.019'], [1527162487.257, '0.018'], [1527162502.257, '0.018'], [1527162517.257, '0.019'], [1527162532.257, '0.019'], [1527162547.257, '0.019'], [1527162562.257, '0.019'], [1527162577.257, '0.019'], [1527162592.257, '0.019'], [1527162607.257, '0.019'], [1527162622.257, '0.02'], [1527162637.257, '0.019'], [1527162652.257, '0.019'], [1527162667.257, '0.019'], [1527162682.257, '0.019'], [1527162697.257, '0.018'], [1527162712.257, '0.019'], [1527162727.257, '0.019'], [1527162742.257, '0.019'], [1527162757.257, '0.019'], [1527162772.257, '0.018'], [1527162787.257, '0.018'], [1527162802.257, '0.018'], [1527162817.257, '0.018'], [1527162832.257, '0.018'], [1527162847.257, '0.018'], [1527162862.257, '0.019'], [1527162877.257, '0.019'], [1527162892.257, '0.018'], [1527162907.257, '0.018'], [1527162922.257, '0.018'], [1527162937.257, '0.018'], [1527162952.257, '0.018'], [1527162967.257, '0.019'], [1527162982.257, '0.019'], [1527162997.257, '0.019'], [1527163012.257, '0.018'], [1527163027.257, '0.019'], [1527163042.257, '0.018'], [1527163057.257, '0.018'], [1527163072.257, '0.019'], [1527163087.257, '0.019'], [1527163102.257, '0.019'], [1527163117.257, '0.019'], [1527163132.257, '0.02'], [1527163147.257, '0.019'], [1527163162.257, '0.019'], [1527163177.257, '0.019'], [1527163192.257, '0.018'], [1527163207.257, '0.018'], [1527163222.257, '0.018'], [1527163237.257, '0.017']]}]}, 'median': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.01'], [1527161452.257, '0.01'], [1527161467.257, '0.01'], [1527161482.257, '0.01'], [1527161497.257, '0.01'], [1527161512.257, '0.01'], [1527161527.257, '0.011'], [1527161542.257, '0.012'], [1527161557.257, '0.011'], [1527161572.257, '0.012'], [1527161587.257, '0.011'], [1527161602.257, '0.011'], [1527161617.257, '0.011'], [1527161632.257, '0.011'], [1527161647.257, '0.011'], [1527161662.257, '0.01'], [1527161677.257, '0.01'], [1527161692.257, '0.01'], [1527161707.257, '0.01'], [1527161722.257, '0.01'], [1527161737.257, '0.01'], [1527161752.257, '0.011'], [1527161767.257, '0.011'], [1527161782.257, '0.011'], [1527161797.257, '0.011'], [1527161812.257, '0.011'], [1527161827.257, '0.011'], [1527161842.257, '0.01'], [1527161857.257, '0.01'], [1527161872.257, '0.01'], [1527161887.257, '0.01'], [1527161902.257, '0.01'], [1527161917.257, '0.01'], [1527161932.257, '0.01'], [1527161947.257, '0.01'], [1527161962.257, '0.011'], [1527161977.257, '0.01'], [1527161992.257, '0.01'], [1527162007.257, '0.01'], [1527162022.257, '0.01'], [1527162037.257, '0.01'], [1527162052.257, '0.01'], [1527162067.257, '0.01'], [1527162082.257, '0.01'], [1527162097.257, '0.01'], [1527162112.257, '0.01'], [1527162127.257, '0.01'], [1527162142.257, '0.01'], [1527162157.257, '0.01'], [1527162172.257, '0.01'], [1527162187.257, '0.01'], [1527162202.257, '0.01'], [1527162217.257, '0.01'], [1527162232.257, '0.009'], [1527162247.257, '0.01'], [1527162262.257, '0.01'], [1527162277.257, '0.01'], [1527162292.257, '0.01'], [1527162307.257, '0.01'], [1527162322.257, '0.01'], [1527162337.257, '0.01'], [1527162352.257, '0.01'], [1527162367.257, '0.01'], [1527162382.257, '0.01'], [1527162397.257, '0.01'], [1527162412.257, '0.01'], [1527162427.257, '0.01'], [1527162442.257, '0.01'], [1527162457.257, '0.01'], [1527162472.257, '0.01'], [1527162487.257, '0.01'], [1527162502.257, '0.01'], [1527162517.257, '0.01'], [1527162532.257, '0.009'], [1527162547.257, '0.01'], [1527162562.257, '0.009'], [1527162577.257, '0.009'], [1527162592.257, '0.009'], [1527162607.257, '0.009'], [1527162622.257, '0.01'], [1527162637.257, '0.009'], [1527162652.257, '0.009'], [1527162667.257, '0.009'], [1527162682.257, '0.009'], [1527162697.257, '0.009'], [1527162712.257, '0.01'], [1527162727.257, '0.009'], [1527162742.257, '0.01'], [1527162757.257, '0.01'], [1527162772.257, '0.009'], [1527162787.257, '0.009'], [1527162802.257, '0.009'], [1527162817.257, '0.009'], [1527162832.257, '0.01'], [1527162847.257, '0.01'], [1527162862.257, '0.01'], [1527162877.257, '0.01'], [1527162892.257, '0.009'], [1527162907.257, '0.009'], [1527162922.257, '0.009'], [1527162937.257, '0.01'], [1527162952.257, '0.01'], [1527162967.257, '0.01'], [1527162982.257, '0.01'], [1527162997.257, '0.009'], [1527163012.257, '0.009'], [1527163027.257, '0.009'], [1527163042.257, '0.009'], [1527163057.257, '0.009'], [1527163072.257, '0.01'], [1527163087.257, '0.01'], [1527163102.257, '0.01'], [1527163117.257, '0.01'], [1527163132.257, '0.01'], [1527163147.257, '0.01'], [1527163162.257, '0.01'], [1527163177.257, '0.01'], [1527163192.257, '0.01'], [1527163207.257, '0.009'], [1527163222.257, '0.009'], [1527163237.257, '0.009']]}]}, 'percentile95': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.084'], [1527161452.257, '0.083'], [1527161467.257, '0.082'], [1527161482.257, '0.081'], [1527161497.257, '0.081'], [1527161512.257, '0.082'], [1527161527.257, '0.083'], [1527161542.257, '0.084'], [1527161557.257, '0.084'], [1527161572.257, '0.085'], [1527161587.257, '0.084'], [1527161602.257, '0.085'], [1527161617.257, '0.084'], [1527161632.257, '0.082'], [1527161647.257, '0.078'], [1527161662.257, '0.073'], [1527161677.257, '0.076'], [1527161692.257, '0.074'], [1527161707.257, '0.077'], [1527161722.257, '0.075'], [1527161737.257, '0.076'], [1527161752.257, '0.079'], [1527161767.257, '0.075'], [1527161782.257, '0.08'], [1527161797.257, '0.076'], [1527161812.257, '0.079'], [1527161827.257, '0.078'], [1527161842.257, '0.077'], [1527161857.257, '0.072'], [1527161872.257, '0.061'], [1527161887.257, '0.066'], [1527161902.257, '0.068'], [1527161917.257, '0.072'], [1527161932.257, '0.074'], [1527161947.257, '0.078'], [1527161962.257, '0.078'], [1527161977.257, '0.074'], [1527161992.257, '0.075'], [1527162007.257, '0.068'], [1527162022.257, '0.072'], [1527162037.257, '0.072'], [1527162052.257, '0.073'], [1527162067.257, '0.079'], [1527162082.257, '0.082'], [1527162097.257, '0.078'], [1527162112.257, '0.08'], [1527162127.257, '0.076'], [1527162142.257, '0.078'], [1527162157.257, '0.075'], [1527162172.257, '0.073'], [1527162187.257, '0.069'], [1527162202.257, '0.067'], [1527162217.257, '0.07'], [1527162232.257, '0.067'], [1527162247.257, '0.064'], [1527162262.257, '0.054'], [1527162277.257, '0.054'], [1527162292.257, '0.064'], [1527162307.257, '0.072'], [1527162322.257, '0.075'], [1527162337.257, '0.077'], [1527162352.257, '0.08'], [1527162367.257, '0.078'], [1527162382.257, '0.079'], [1527162397.257, '0.075'], [1527162412.257, '0.07'], [1527162427.257, '0.075'], [1527162442.257, '0.073'], [1527162457.257, '0.07'], [1527162472.257, '0.065'], [1527162487.257, '0.054'], [1527162502.257, '0.061'], [1527162517.257, '0.066'], [1527162532.257, '0.074'], [1527162547.257, '0.072'], [1527162562.257, '0.069'], [1527162577.257, '0.068'], [1527162592.257, '0.072'], [1527162607.257, '0.077'], [1527162622.257, '0.079'], [1527162637.257, '0.074'], [1527162652.257, '0.074'], [1527162667.257, '0.069'], [1527162682.257, '0.066'], [1527162697.257, '0.061'], [1527162712.257, '0.066'], [1527162727.257, '0.068'], [1527162742.257, '0.066'], [1527162757.257, '0.061'], [1527162772.257, '0.061'], [1527162787.257, '0.067'], [1527162802.257, '0.064'], [1527162817.257, '0.07'], [1527162832.257, '0.064'], [1527162847.257, '0.066'], [1527162862.257, '0.068'], [1527162877.257, '0.058'], [1527162892.257, '0.054'], [1527162907.257, '0.054'], [1527162922.257, '0.061'], [1527162937.257, '0.069'], [1527162952.257, '0.064'], [1527162967.257, '0.068'], [1527162982.257, '0.072'], [1527162997.257, '0.072'], [1527163012.257, '0.071'], [1527163027.257, '0.072'], [1527163042.257, '0.064'], [1527163057.257, '0.062'], [1527163072.257, '0.064'], [1527163087.257, '0.07'], [1527163102.257, '0.072'], [1527163117.257, '0.069'], [1527163132.257, '0.075'], [1527163147.257, '0.073'], [1527163162.257, '0.07'], [1527163177.257, '0.07'], [1527163192.257, '0.058'], [1527163207.257, '0.055'], [1527163222.257, '0.064'], [1527163237.257, '0.062']]}]}, 'percentile99': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.097'], [1527161452.257, '0.097'], [1527161467.257, '0.096'], [1527161482.257, '0.096'], [1527161497.257, '0.096'], [1527161512.257, '0.096'], [1527161527.257, '0.097'], [1527161542.257, '0.097'], [1527161557.257, '0.097'], [1527161572.257, '0.097'], [1527161587.257, '0.097'], [1527161602.257, '0.098'], [1527161617.257, '0.098'], [1527161632.257, '0.098'], [1527161647.257, '0.098'], [1527161662.257, '0.095'], [1527161677.257, '0.095'], [1527161692.257, '0.095'], [1527161707.257, '0.095'], [1527161722.257, '0.095'], [1527161737.257, '0.095'], [1527161752.257, '0.096'], [1527161767.257, '0.095'], [1527161782.257, '0.098'], [1527161797.257, '0.097'], [1527161812.257, '0.098'], [1527161827.257, '0.098'], [1527161842.257, '0.095'], [1527161857.257, '0.094'], [1527161872.257, '0.092'], [1527161887.257, '0.093'], [1527161902.257, '0.094'], [1527161917.257, '0.094'], [1527161932.257, '0.095'], [1527161947.257, '0.096'], [1527161962.257, '0.096'], [1527161977.257, '0.095'], [1527161992.257, '0.095'], [1527162007.257, '0.094'], [1527162022.257, '0.094'], [1527162037.257, '0.094'], [1527162052.257, '0.095'], [1527162067.257, '0.096'], [1527162082.257, '0.096'], [1527162097.257, '0.096'], [1527162112.257, '0.096'], [1527162127.257, '0.095'], [1527162142.257, '0.096'], [1527162157.257, '0.095'], [1527162172.257, '0.095'], [1527162187.257, '0.094'], [1527162202.257, '0.093'], [1527162217.257, '0.094'], [1527162232.257, '0.093'], [1527162247.257, '0.093'], [1527162262.257, '0.091'], [1527162277.257, '0.091'], [1527162292.257, '0.093'], [1527162307.257, '0.094'], [1527162322.257, '0.095'], [1527162337.257, '0.095'], [1527162352.257, '0.096'], [1527162367.257, '0.096'], [1527162382.257, '0.096'], [1527162397.257, '0.095'], [1527162412.257, '0.094'], [1527162427.257, '0.095'], [1527162442.257, '0.095'], [1527162457.257, '0.094'], [1527162472.257, '0.093'], [1527162487.257, '0.091'], [1527162502.257, '0.092'], [1527162517.257, '0.093'], [1527162532.257, '0.095'], [1527162547.257, '0.094'], [1527162562.257, '0.094'], [1527162577.257, '0.094'], [1527162592.257, '0.094'], [1527162607.257, '0.095'], [1527162622.257, '0.096'], [1527162637.257, '0.095'], [1527162652.257, '0.095'], [1527162667.257, '0.094'], [1527162682.257, '0.093'], [1527162697.257, '0.092'], [1527162712.257, '0.093'], [1527162727.257, '0.094'], [1527162742.257, '0.093'], [1527162757.257, '0.092'], [1527162772.257, '0.092'], [1527162787.257, '0.093'], [1527162802.257, '0.093'], [1527162817.257, '0.094'], [1527162832.257, '0.093'], [1527162847.257, '0.093'], [1527162862.257, '0.094'], [1527162877.257, '0.092'], [1527162892.257, '0.091'], [1527162907.257, '0.091'], [1527162922.257, '0.092'], [1527162937.257, '0.094'], [1527162952.257, '0.093'], [1527162967.257, '0.094'], [1527162982.257, '0.094'], [1527162997.257, '0.094'], [1527163012.257, '0.094'], [1527163027.257, '0.094'], [1527163042.257, '0.093'], [1527163057.257, '0.092'], [1527163072.257, '0.093'], [1527163087.257, '0.094'], [1527163102.257, '0.094'], [1527163117.257, '0.094'], [1527163132.257, '0.097'], [1527163147.257, '0.097'], [1527163162.257, '0.097'], [1527163177.257, '0.097'], [1527163192.257, '0.092'], [1527163207.257, '0.091'], [1527163222.257, '0.093'], [1527163237.257, '0.092']]}]}}, 'request_duration_out': {'average': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.01'], [1527161452.257, '0.01'], [1527161467.257, '0.01'], [1527161482.257, '0.01'], [1527161497.257, '0.01'], [1527161512.257, '0.01'], [1527161527.257, '0.01'], [1527161542.257, '0.01'], [1527161557.257, '0.01'], [1527161572.257, '0.01'], [1527161587.257, '0.01'], [1527161602.257, '0.011'], [1527161617.257, '0.01'], [1527161632.257, '0.01'], [1527161647.257, '0.009'], [1527161662.257, '0.008'], [1527161677.257, '0.008'], [1527161692.257, '0.008'], [1527161707.257, '0.009'], [1527161722.257, '0.009'], [1527161737.257, '0.009'], [1527161752.257, '0.009'], [1527161767.257, '0.009'], [1527161782.257, '0.009'], [1527161797.257, '0.009'], [1527161812.257, '0.009'], [1527161827.257, '0.009'], [1527161842.257, '0.009'], [1527161857.257, '0.009'], [1527161872.257, '0.008'], [1527161887.257, '0.008'], [1527161902.257, '0.008'], [1527161917.257, '0.008'], [1527161932.257, '0.009'], [1527161947.257, '0.009'], [1527161962.257, '0.009'], [1527161977.257, '0.009'], [1527161992.257, '0.009'], [1527162007.257, '0.008'], [1527162022.257, '0.009'], [1527162037.257, '0.009'], [1527162052.257, '0.009'], [1527162067.257, '0.009'], [1527162082.257, '0.009'], [1527162097.257, '0.009'], [1527162112.257, '0.009'], [1527162127.257, '0.009'], [1527162142.257, '0.009'], [1527162157.257, '0.009'], [1527162172.257, '0.009'], [1527162187.257, '0.009'], [1527162202.257, '0.009'], [1527162217.257, '0.009'], [1527162232.257, '0.008'], [1527162247.257, '0.008'], [1527162262.257, '0.008'], [1527162277.257, '0.008'], [1527162292.257, '0.008'], [1527162307.257, '0.009'], [1527162322.257, '0.009'], [1527162337.257, '0.009'], [1527162352.257, '0.009'], [1527162367.257, '0.009'], [1527162382.257, '0.009'], [1527162397.257, '0.009'], [1527162412.257, '0.008'], [1527162427.257, '0.009'], [1527162442.257, '0.009'], [1527162457.257, '0.009'], [1527162472.257, '0.008'], [1527162487.257, '0.008'], [1527162502.257, '0.008'], [1527162517.257, '0.008'], [1527162532.257, '0.008'], [1527162547.257, '0.009'], [1527162562.257, '0.008'], [1527162577.257, '0.008'], [1527162592.257, '0.008'], [1527162607.257, '0.009'], [1527162622.257, '0.009'], [1527162637.257, '0.009'], [1527162652.257, '0.008'], [1527162667.257, '0.008'], [1527162682.257, '0.008'], [1527162697.257, '0.008'], [1527162712.257, '0.009'], [1527162727.257, '0.008'], [1527162742.257, '0.008'], [1527162757.257, '0.008'], [1527162772.257, '0.008'], [1527162787.257, '0.008'], [1527162802.257, '0.008'], [1527162817.257, '0.008'], [1527162832.257, '0.008'], [1527162847.257, '0.008'], [1527162862.257, '0.008'], [1527162877.257, '0.008'], [1527162892.257, '0.008'], [1527162907.257, '0.008'], [1527162922.257, '0.008'], [1527162937.257, '0.008'], [1527162952.257, '0.008'], [1527162967.257, '0.008'], [1527162982.257, '0.008'], [1527162997.257, '0.008'], [1527163012.257, '0.008'], [1527163027.257, '0.008'], [1527163042.257, '0.008'], [1527163057.257, '0.008'], [1527163072.257, '0.008'], [1527163087.257, '0.008'], [1527163102.257, '0.008'], [1527163117.257, '0.008'], [1527163132.257, '0.009'], [1527163147.257, '0.008'], [1527163162.257, '0.009'], [1527163177.257, '0.008'], [1527163192.257, '0.008'], [1527163207.257, '0.008'], [1527163222.257, '0.008'], [1527163237.257, '0.008']]}]}, 'median': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.007'], [1527161452.257, '0.007'], [1527161467.257, '0.007'], [1527161482.257, '0.007'], [1527161497.257, '0.007'], [1527161512.257, '0.007'], [1527161527.257, '0.007'], [1527161542.257, '0.007'], [1527161557.257, '0.008'], [1527161572.257, '0.008'], [1527161587.257, '0.008'], [1527161602.257, '0.008'], [1527161617.257, '0.008'], [1527161632.257, '0.008'], [1527161647.257, '0.007'], [1527161662.257, '0.007'], [1527161677.257, '0.007'], [1527161692.257, '0.007'], [1527161707.257, '0.007'], [1527161722.257, '0.007'], [1527161737.257, '0.007'], [1527161752.257, '0.007'], [1527161767.257, '0.007'], [1527161782.257, '0.008'], [1527161797.257, '0.008'], [1527161812.257, '0.008'], [1527161827.257, '0.007'], [1527161842.257, '0.007'], [1527161857.257, '0.007'], [1527161872.257, '0.007'], [1527161887.257, '0.007'], [1527161902.257, '0.007'], [1527161917.257, '0.007'], [1527161932.257, '0.007'], [1527161947.257, '0.007'], [1527161962.257, '0.007'], [1527161977.257, '0.007'], [1527161992.257, '0.007'], [1527162007.257, '0.007'], [1527162022.257, '0.007'], [1527162037.257, '0.007'], [1527162052.257, '0.007'], [1527162067.257, '0.007'], [1527162082.257, '0.007'], [1527162097.257, '0.007'], [1527162112.257, '0.007'], [1527162127.257, '0.007'], [1527162142.257, '0.007'], [1527162157.257, '0.007'], [1527162172.257, '0.007'], [1527162187.257, '0.007'], [1527162202.257, '0.007'], [1527162217.257, '0.007'], [1527162232.257, '0.007'], [1527162247.257, '0.007'], [1527162262.257, '0.007'], [1527162277.257, '0.007'], [1527162292.257, '0.007'], [1527162307.257, '0.007'], [1527162322.257, '0.007'], [1527162337.257, '0.007'], [1527162352.257, '0.007'], [1527162367.257, '0.007'], [1527162382.257, '0.007'], [1527162397.257, '0.007'], [1527162412.257, '0.007'], [1527162427.257, '0.007'], [1527162442.257, '0.007'], [1527162457.257, '0.007'], [1527162472.257, '0.007'], [1527162487.257, '0.007'], [1527162502.257, '0.007'], [1527162517.257, '0.007'], [1527162532.257, '0.007'], [1527162547.257, '0.007'], [1527162562.257, '0.007'], [1527162577.257, '0.007'], [1527162592.257, '0.007'], [1527162607.257, '0.007'], [1527162622.257, '0.007'], [1527162637.257, '0.007'], [1527162652.257, '0.006'], [1527162667.257, '0.006'], [1527162682.257, '0.006'], [1527162697.257, '0.006'], [1527162712.257, '0.006'], [1527162727.257, '0.006'], [1527162742.257, '0.007'], [1527162757.257, '0.007'], [1527162772.257, '0.007'], [1527162787.257, '0.007'], [1527162802.257, '0.006'], [1527162817.257, '0.006'], [1527162832.257, '0.006'], [1527162847.257, '0.006'], [1527162862.257, '0.007'], [1527162877.257, '0.007'], [1527162892.257, '0.007'], [1527162907.257, '0.006'], [1527162922.257, '0.007'], [1527162937.257, '0.007'], [1527162952.257, '0.006'], [1527162967.257, '0.007'], [1527162982.257, '0.006'], [1527162997.257, '0.006'], [1527163012.257, '0.006'], [1527163027.257, '0.006'], [1527163042.257, '0.007'], [1527163057.257, '0.007'], [1527163072.257, '0.007'], [1527163087.257, '0.007'], [1527163102.257, '0.007'], [1527163117.257, '0.007'], [1527163132.257, '0.007'], [1527163147.257, '0.007'], [1527163162.257, '0.007'], [1527163177.257, '0.007'], [1527163192.257, '0.006'], [1527163207.257, '0.006'], [1527163222.257, '0.005'], [1527163237.257, '0.005']]}]}, 'percentile95': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.036'], [1527161452.257, '0.033'], [1527161467.257, '0.033'], [1527161482.257, '0.036'], [1527161497.257, '0.035'], [1527161512.257, '0.036'], [1527161527.257, '0.036'], [1527161542.257, '0.037'], [1527161557.257, '0.039'], [1527161572.257, '0.04'], [1527161587.257, '0.039'], [1527161602.257, '0.039'], [1527161617.257, '0.034'], [1527161632.257, '0.032'], [1527161647.257, '0.025'], [1527161662.257, '0.023'], [1527161677.257, '0.023'], [1527161692.257, '0.023'], [1527161707.257, '0.023'], [1527161722.257, '0.024'], [1527161737.257, '0.024'], [1527161752.257, '0.024'], [1527161767.257, '0.024'], [1527161782.257, '0.024'], [1527161797.257, '0.023'], [1527161812.257, '0.024'], [1527161827.257, '0.023'], [1527161842.257, '0.023'], [1527161857.257, '0.023'], [1527161872.257, '0.023'], [1527161887.257, '0.023'], [1527161902.257, '0.023'], [1527161917.257, '0.023'], [1527161932.257, '0.023'], [1527161947.257, '0.023'], [1527161962.257, '0.023'], [1527161977.257, '0.023'], [1527161992.257, '0.023'], [1527162007.257, '0.023'], [1527162022.257, '0.023'], [1527162037.257, '0.023'], [1527162052.257, '0.023'], [1527162067.257, '0.023'], [1527162082.257, '0.023'], [1527162097.257, '0.022'], [1527162112.257, '0.022'], [1527162127.257, '0.023'], [1527162142.257, '0.023'], [1527162157.257, '0.023'], [1527162172.257, '0.024'], [1527162187.257, '0.024'], [1527162202.257, '0.024'], [1527162217.257, '0.024'], [1527162232.257, '0.022'], [1527162247.257, '0.022'], [1527162262.257, '0.023'], [1527162277.257, '0.023'], [1527162292.257, '0.023'], [1527162307.257, '0.023'], [1527162322.257, '0.023'], [1527162337.257, '0.024'], [1527162352.257, '0.024'], [1527162367.257, '0.024'], [1527162382.257, '0.024'], [1527162397.257, '0.023'], [1527162412.257, '0.023'], [1527162427.257, '0.023'], [1527162442.257, '0.023'], [1527162457.257, '0.023'], [1527162472.257, '0.023'], [1527162487.257, '0.023'], [1527162502.257, '0.022'], [1527162517.257, '0.023'], [1527162532.257, '0.023'], [1527162547.257, '0.023'], [1527162562.257, '0.023'], [1527162577.257, '0.023'], [1527162592.257, '0.023'], [1527162607.257, '0.023'], [1527162622.257, '0.023'], [1527162637.257, '0.024'], [1527162652.257, '0.024'], [1527162667.257, '0.024'], [1527162682.257, '0.024'], [1527162697.257, '0.023'], [1527162712.257, '0.024'], [1527162727.257, '0.024'], [1527162742.257, '0.024'], [1527162757.257, '0.024'], [1527162772.257, '0.023'], [1527162787.257, '0.023'], [1527162802.257, '0.022'], [1527162817.257, '0.023'], [1527162832.257, '0.023'], [1527162847.257, '0.023'], [1527162862.257, '0.023'], [1527162877.257, '0.023'], [1527162892.257, '0.022'], [1527162907.257, '0.022'], [1527162922.257, '0.022'], [1527162937.257, '0.023'], [1527162952.257, '0.023'], [1527162967.257, '0.024'], [1527162982.257, '0.024'], [1527162997.257, '0.023'], [1527163012.257, '0.022'], [1527163027.257, '0.022'], [1527163042.257, '0.023'], [1527163057.257, '0.023'], [1527163072.257, '0.023'], [1527163087.257, '0.022'], [1527163102.257, '0.023'], [1527163117.257, '0.023'], [1527163132.257, '0.023'], [1527163147.257, '0.023'], [1527163162.257, '0.023'], [1527163177.257, '0.023'], [1527163192.257, '0.023'], [1527163207.257, '0.023'], [1527163222.257, '0.023'], [1527163237.257, '0.023']]}]}, 'percentile99': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.047'], [1527161452.257, '0.047'], [1527161467.257, '0.047'], [1527161482.257, '0.047'], [1527161497.257, '0.047'], [1527161512.257, '0.047'], [1527161527.257, '0.047'], [1527161542.257, '0.047'], [1527161557.257, '0.048'], [1527161572.257, '0.048'], [1527161587.257, '0.048'], [1527161602.257, '0.049'], [1527161617.257, '0.049'], [1527161632.257, '0.049'], [1527161647.257, '0.048'], [1527161662.257, '0.025'], [1527161677.257, '0.025'], [1527161692.257, '0.025'], [1527161707.257, '0.032'], [1527161722.257, '0.038'], [1527161737.257, '0.041'], [1527161752.257, '0.043'], [1527161767.257, '0.041'], [1527161782.257, '0.041'], [1527161797.257, '0.032'], [1527161812.257, '0.038'], [1527161827.257, '0.025'], [1527161842.257, '0.031'], [1527161857.257, '0.025'], [1527161872.257, '0.025'], [1527161887.257, '0.025'], [1527161902.257, '0.025'], [1527161917.257, '0.025'], [1527161932.257, '0.032'], [1527161947.257, '0.025'], [1527161962.257, '0.025'], [1527161977.257, '0.025'], [1527161992.257, '0.032'], [1527162007.257, '0.032'], [1527162022.257, '0.032'], [1527162037.257, '0.032'], [1527162052.257, '0.025'], [1527162067.257, '0.025'], [1527162082.257, '0.025'], [1527162097.257, '0.024'], [1527162112.257, '0.024'], [1527162127.257, '0.025'], [1527162142.257, '0.025'], [1527162157.257, '0.025'], [1527162172.257, '0.041'], [1527162187.257, '0.041'], [1527162202.257, '0.041'], [1527162217.257, '0.041'], [1527162232.257, '0.024'], [1527162247.257, '0.024'], [1527162262.257, '0.025'], [1527162277.257, '0.025'], [1527162292.257, '0.032'], [1527162307.257, '0.032'], [1527162322.257, '0.032'], [1527162337.257, '0.041'], [1527162352.257, '0.043'], [1527162367.257, '0.044'], [1527162382.257, '0.041'], [1527162397.257, '0.038'], [1527162412.257, '0.025'], [1527162427.257, '0.025'], [1527162442.257, '0.032'], [1527162457.257, '0.031'], [1527162472.257, '0.025'], [1527162487.257, '0.025'], [1527162502.257, '0.024'], [1527162517.257, '0.025'], [1527162532.257, '0.032'], [1527162547.257, '0.032'], [1527162562.257, '0.038'], [1527162577.257, '0.032'], [1527162592.257, '0.025'], [1527162607.257, '0.025'], [1527162622.257, '0.038'], [1527162637.257, '0.046'], [1527162652.257, '0.047'], [1527162667.257, '0.047'], [1527162682.257, '0.041'], [1527162697.257, '0.025'], [1527162712.257, '0.041'], [1527162727.257, '0.043'], [1527162742.257, '0.044'], [1527162757.257, '0.041'], [1527162772.257, '0.038'], [1527162787.257, '0.025'], [1527162802.257, '0.024'], [1527162817.257, '0.025'], [1527162832.257, '0.032'], [1527162847.257, '0.038'], [1527162862.257, '0.038'], [1527162877.257, '0.038'], [1527162892.257, '0.025'], [1527162907.257, '0.024'], [1527162922.257, '0.024'], [1527162937.257, '0.032'], [1527162952.257, '0.038'], [1527162967.257, '0.043'], [1527162982.257, '0.041'], [1527162997.257, '0.038'], [1527163012.257, '0.025'], [1527163027.257, '0.025'], [1527163042.257, '0.025'], [1527163057.257, '0.025'], [1527163072.257, '0.025'], [1527163087.257, '0.024'], [1527163102.257, '0.025'], [1527163117.257, '0.025'], [1527163132.257, '0.038'], [1527163147.257, '0.038'], [1527163162.257, '0.038'], [1527163177.257, '0.038'], [1527163192.257, '0.032'], [1527163207.257, '0.032'], [1527163222.257, '0.038'], [1527163237.257, '0.038']]}]}}, 'request_size_in': {'average': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0'], [1527161452.257, '0'], [1527161467.257, '0'], [1527161482.257, '0'], [1527161497.257, '0'], [1527161512.257, '0'], [1527161527.257, '0'], [1527161542.257, '0'], [1527161557.257, '0'], [1527161572.257, '0'], [1527161587.257, '0'], [1527161602.257, '0'], [1527161617.257, '0'], [1527161632.257, '0'], [1527161647.257, '0'], [1527161662.257, '0'], [1527161677.257, '0'], [1527161692.257, '0'], [1527161707.257, '0'], [1527161722.257, '0'], [1527161737.257, '0'], [1527161752.257, '0'], [1527161767.257, '0'], [1527161782.257, '0'], [1527161797.257, '0'], [1527161812.257, '0'], [1527161827.257, '0'], [1527161842.257, '0'], [1527161857.257, '0'], [1527161872.257, '0'], [1527161887.257, '0'], [1527161902.257, '0'], [1527161917.257, '0'], [1527161932.257, '0'], [1527161947.257, '0'], [1527161962.257, '0'], [1527161977.257, '0'], [1527161992.257, '0'], [1527162007.257, '0'], [1527162022.257, '0'], [1527162037.257, '0'], [1527162052.257, '0'], [1527162067.257, '0'], [1527162082.257, '0'], [1527162097.257, '0'], [1527162112.257, '0'], [1527162127.257, '0'], [1527162142.257, '0'], [1527162157.257, '0'], [1527162172.257, '0'], [1527162187.257, '0'], [1527162202.257, '0'], [1527162217.257, '0'], [1527162232.257, '0'], [1527162247.257, '0'], [1527162262.257, '0'], [1527162277.257, '0'], [1527162292.257, '0'], [1527162307.257, '0'], [1527162322.257, '0'], [1527162337.257, '0'], [1527162352.257, '0'], [1527162367.257, '0'], [1527162382.257, '0'], [1527162397.257, '0'], [1527162412.257, '0'], [1527162427.257, '0'], [1527162442.257, '0'], [1527162457.257, '0'], [1527162472.257, '0'], [1527162487.257, '0'], [1527162502.257, '0'], [1527162517.257, '0'], [1527162532.257, '0'], [1527162547.257, '0'], [1527162562.257, '0'], [1527162577.257, '0'], [1527162592.257, '0'], [1527162607.257, '0'], [1527162622.257, '0'], [1527162637.257, '0'], [1527162652.257, '0'], [1527162667.257, '0'], [1527162682.257, '0'], [1527162697.257, '0'], [1527162712.257, '0'], [1527162727.257, '0'], [1527162742.257, '0'], [1527162757.257, '0'], [1527162772.257, '0'], [1527162787.257, '0'], [1527162802.257, '0'], [1527162817.257, '0'], [1527162832.257, '0'], [1527162847.257, '0'], [1527162862.257, '0'], [1527162877.257, '0'], [1527162892.257, '0'], [1527162907.257, '0'], [1527162922.257, '0'], [1527162937.257, '0'], [1527162952.257, '0'], [1527162967.257, '0'], [1527162982.257, '0'], [1527162997.257, '0'], [1527163012.257, '0'], [1527163027.257, '0'], [1527163042.257, '0'], [1527163057.257, '0'], [1527163072.257, '0'], [1527163087.257, '0'], [1527163102.257, '0'], [1527163117.257, '0'], [1527163132.257, '0'], [1527163147.257, '0'], [1527163162.257, '0'], [1527163177.257, '0'], [1527163192.257, '0'], [1527163207.257, '0'], [1527163222.257, '0'], [1527163237.257, '0']]}]}, 'median': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.5'], [1527161452.257, '0.5'], [1527161467.257, '0.5'], [1527161482.257, '0.5'], [1527161497.257, '0.5'], [1527161512.257, '0.5'], [1527161527.257, '0.5'], [1527161542.257, '0.5'], [1527161557.257, '0.5'], [1527161572.257, '0.5'], [1527161587.257, '0.5'], [1527161602.257, '0.5'], [1527161617.257, '0.5'], [1527161632.257, '0.5'], [1527161647.257, '0.5'], [1527161662.257, '0.5'], [1527161677.257, '0.5'], [1527161692.257, '0.5'], [1527161707.257, '0.5'], [1527161722.257, '0.5'], [1527161737.257, '0.5'], [1527161752.257, '0.5'], [1527161767.257, '0.5'], [1527161782.257, '0.5'], [1527161797.257, '0.5'], [1527161812.257, '0.5'], [1527161827.257, '0.5'], [1527161842.257, '0.5'], [1527161857.257, '0.5'], [1527161872.257, '0.5'], [1527161887.257, '0.5'], [1527161902.257, '0.5'], [1527161917.257, '0.5'], [1527161932.257, '0.5'], [1527161947.257, '0.5'], [1527161962.257, '0.5'], [1527161977.257, '0.5'], [1527161992.257, '0.5'], [1527162007.257, '0.5'], [1527162022.257, '0.5'], [1527162037.257, '0.5'], [1527162052.257, '0.5'], [1527162067.257, '0.5'], [1527162082.257, '0.5'], [1527162097.257, '0.5'], [1527162112.257, '0.5'], [1527162127.257, '0.5'], [1527162142.257, '0.5'], [1527162157.257, '0.5'], [1527162172.257, '0.5'], [1527162187.257, '0.5'], [1527162202.257, '0.5'], [1527162217.257, '0.5'], [1527162232.257, '0.5'], [1527162247.257, '0.5'], [1527162262.257, '0.5'], [1527162277.257, '0.5'], [1527162292.257, '0.5'], [1527162307.257, '0.5'], [1527162322.257, '0.5'], [1527162337.257, '0.5'], [1527162352.257, '0.5'], [1527162367.257, '0.5'], [1527162382.257, '0.5'], [1527162397.257, '0.5'], [1527162412.257, '0.5'], [1527162427.257, '0.5'], [1527162442.257, '0.5'], [1527162457.257, '0.5'], [1527162472.257, '0.5'], [1527162487.257, '0.5'], [1527162502.257, '0.5'], [1527162517.257, '0.5'], [1527162532.257, '0.5'], [1527162547.257, '0.5'], [1527162562.257, '0.5'], [1527162577.257, '0.5'], [1527162592.257, '0.5'], [1527162607.257, '0.5'], [1527162622.257, '0.5'], [1527162637.257, '0.5'], [1527162652.257, '0.5'], [1527162667.257, '0.5'], [1527162682.257, '0.5'], [1527162697.257, '0.5'], [1527162712.257, '0.5'], [1527162727.257, '0.5'], [1527162742.257, '0.5'], [1527162757.257, '0.5'], [1527162772.257, '0.5'], [1527162787.257, '0.5'], [1527162802.257, '0.5'], [1527162817.257, '0.5'], [1527162832.257, '0.5'], [1527162847.257, '0.5'], [1527162862.257, '0.5'], [1527162877.257, '0.5'], [1527162892.257, '0.5'], [1527162907.257, '0.5'], [1527162922.257, '0.5'], [1527162937.257, '0.5'], [1527162952.257, '0.5'], [1527162967.257, '0.5'], [1527162982.257, '0.5'], [1527162997.257, '0.5'], [1527163012.257, '0.5'], [1527163027.257, '0.5'], [1527163042.257, '0.5'], [1527163057.257, '0.5'], [1527163072.257, '0.5'], [1527163087.257, '0.5'], [1527163102.257, '0.5'], [1527163117.257, '0.5'], [1527163132.257, '0.5'], [1527163147.257, '0.5'], [1527163162.257, '0.5'], [1527163177.257, '0.5'], [1527163192.257, '0.5'], [1527163207.257, '0.5'], [1527163222.257, '0.5'], [1527163237.257, '0.5']]}]}, 'percentile95': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.95'], [1527161452.257, '0.95'], [1527161467.257, '0.95'], [1527161482.257, '0.95'], [1527161497.257, '0.95'], [1527161512.257, '0.95'], [1527161527.257, '0.95'], [1527161542.257, '0.95'], [1527161557.257, '0.95'], [1527161572.257, '0.95'], [1527161587.257, '0.95'], [1527161602.257, '0.95'], [1527161617.257, '0.95'], [1527161632.257, '0.95'], [1527161647.257, '0.95'], [1527161662.257, '0.95'], [1527161677.257, '0.95'], [1527161692.257, '0.95'], [1527161707.257, '0.95'], [1527161722.257, '0.95'], [1527161737.257, '0.95'], [1527161752.257, '0.95'], [1527161767.257, '0.95'], [1527161782.257, '0.95'], [1527161797.257, '0.95'], [1527161812.257, '0.95'], [1527161827.257, '0.95'], [1527161842.257, '0.95'], [1527161857.257, '0.95'], [1527161872.257, '0.95'], [1527161887.257, '0.95'], [1527161902.257, '0.95'], [1527161917.257, '0.95'], [1527161932.257, '0.95'], [1527161947.257, '0.95'], [1527161962.257, '0.95'], [1527161977.257, '0.95'], [1527161992.257, '0.95'], [1527162007.257, '0.95'], [1527162022.257, '0.95'], [1527162037.257, '0.95'], [1527162052.257, '0.95'], [1527162067.257, '0.95'], [1527162082.257, '0.95'], [1527162097.257, '0.95'], [1527162112.257, '0.95'], [1527162127.257, '0.95'], [1527162142.257, '0.95'], [1527162157.257, '0.95'], [1527162172.257, '0.95'], [1527162187.257, '0.95'], [1527162202.257, '0.95'], [1527162217.257, '0.95'], [1527162232.257, '0.95'], [1527162247.257, '0.95'], [1527162262.257, '0.95'], [1527162277.257, '0.95'], [1527162292.257, '0.95'], [1527162307.257, '0.95'], [1527162322.257, '0.95'], [1527162337.257, '0.95'], [1527162352.257, '0.95'], [1527162367.257, '0.95'], [1527162382.257, '0.95'], [1527162397.257, '0.95'], [1527162412.257, '0.95'], [1527162427.257, '0.95'], [1527162442.257, '0.95'], [1527162457.257, '0.95'], [1527162472.257, '0.95'], [1527162487.257, '0.95'], [1527162502.257, '0.95'], [1527162517.257, '0.95'], [1527162532.257, '0.95'], [1527162547.257, '0.95'], [1527162562.257, '0.95'], [1527162577.257, '0.95'], [1527162592.257, '0.95'], [1527162607.257, '0.95'], [1527162622.257, '0.95'], [1527162637.257, '0.95'], [1527162652.257, '0.95'], [1527162667.257, '0.95'], [1527162682.257, '0.95'], [1527162697.257, '0.95'], [1527162712.257, '0.95'], [1527162727.257, '0.95'], [1527162742.257, '0.95'], [1527162757.257, '0.95'], [1527162772.257, '0.95'], [1527162787.257, '0.95'], [1527162802.257, '0.95'], [1527162817.257, '0.95'], [1527162832.257, '0.95'], [1527162847.257, '0.95'], [1527162862.257, '0.95'], [1527162877.257, '0.95'], [1527162892.257, '0.95'], [1527162907.257, '0.95'], [1527162922.257, '0.95'], [1527162937.257, '0.95'], [1527162952.257, '0.95'], [1527162967.257, '0.95'], [1527162982.257, '0.95'], [1527162997.257, '0.95'], [1527163012.257, '0.95'], [1527163027.257, '0.95'], [1527163042.257, '0.95'], [1527163057.257, '0.95'], [1527163072.257, '0.95'], [1527163087.257, '0.95'], [1527163102.257, '0.95'], [1527163117.257, '0.95'], [1527163132.257, '0.95'], [1527163147.257, '0.95'], [1527163162.257, '0.95'], [1527163177.257, '0.95'], [1527163192.257, '0.95'], [1527163207.257, '0.95'], [1527163222.257, '0.95'], [1527163237.257, '0.95']]}]}, 'percentile99': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.99'], [1527161452.257, '0.99'], [1527161467.257, '0.99'], [1527161482.257, '0.99'], [1527161497.257, '0.99'], [1527161512.257, '0.99'], [1527161527.257, '0.99'], [1527161542.257, '0.99'], [1527161557.257, '0.99'], [1527161572.257, '0.99'], [1527161587.257, '0.99'], [1527161602.257, '0.99'], [1527161617.257, '0.99'], [1527161632.257, '0.99'], [1527161647.257, '0.99'], [1527161662.257, '0.99'], [1527161677.257, '0.99'], [1527161692.257, '0.99'], [1527161707.257, '0.99'], [1527161722.257, '0.99'], [1527161737.257, '0.99'], [1527161752.257, '0.99'], [1527161767.257, '0.99'], [1527161782.257, '0.99'], [1527161797.257, '0.99'], [1527161812.257, '0.99'], [1527161827.257, '0.99'], [1527161842.257, '0.99'], [1527161857.257, '0.99'], [1527161872.257, '0.99'], [1527161887.257, '0.99'], [1527161902.257, '0.99'], [1527161917.257, '0.99'], [1527161932.257, '0.99'], [1527161947.257, '0.99'], [1527161962.257, '0.99'], [1527161977.257, '0.99'], [1527161992.257, '0.99'], [1527162007.257, '0.99'], [1527162022.257, '0.99'], [1527162037.257, '0.99'], [1527162052.257, '0.99'], [1527162067.257, '0.99'], [1527162082.257, '0.99'], [1527162097.257, '0.99'], [1527162112.257, '0.99'], [1527162127.257, '0.99'], [1527162142.257, '0.99'], [1527162157.257, '0.99'], [1527162172.257, '0.99'], [1527162187.257, '0.99'], [1527162202.257, '0.99'], [1527162217.257, '0.99'], [1527162232.257, '0.99'], [1527162247.257, '0.99'], [1527162262.257, '0.99'], [1527162277.257, '0.99'], [1527162292.257, '0.99'], [1527162307.257, '0.99'], [1527162322.257, '0.99'], [1527162337.257, '0.99'], [1527162352.257, '0.99'], [1527162367.257, '0.99'], [1527162382.257, '0.99'], [1527162397.257, '0.99'], [1527162412.257, '0.99'], [1527162427.257, '0.99'], [1527162442.257, '0.99'], [1527162457.257, '0.99'], [1527162472.257, '0.99'], [1527162487.257, '0.99'], [1527162502.257, '0.99'], [1527162517.257, '0.99'], [1527162532.257, '0.99'], [1527162547.257, '0.99'], [1527162562.257, '0.99'], [1527162577.257, '0.99'], [1527162592.257, '0.99'], [1527162607.257, '0.99'], [1527162622.257, '0.99'], [1527162637.257, '0.99'], [1527162652.257, '0.99'], [1527162667.257, '0.99'], [1527162682.257, '0.99'], [1527162697.257, '0.99'], [1527162712.257, '0.99'], [1527162727.257, '0.99'], [1527162742.257, '0.99'], [1527162757.257, '0.99'], [1527162772.257, '0.99'], [1527162787.257, '0.99'], [1527162802.257, '0.99'], [1527162817.257, '0.99'], [1527162832.257, '0.99'], [1527162847.257, '0.99'], [1527162862.257, '0.99'], [1527162877.257, '0.99'], [1527162892.257, '0.99'], [1527162907.257, '0.99'], [1527162922.257, '0.99'], [1527162937.257, '0.99'], [1527162952.257, '0.99'], [1527162967.257, '0.99'], [1527162982.257, '0.99'], [1527162997.257, '0.99'], [1527163012.257, '0.99'], [1527163027.257, '0.99'], [1527163042.257, '0.99'], [1527163057.257, '0.99'], [1527163072.257, '0.99'], [1527163087.257, '0.99'], [1527163102.257, '0.99'], [1527163117.257, '0.99'], [1527163132.257, '0.99'], [1527163147.257, '0.99'], [1527163162.257, '0.99'], [1527163177.257, '0.99'], [1527163192.257, '0.99'], [1527163207.257, '0.99'], [1527163222.257, '0.99'], [1527163237.257, '0.99']]}]}}, 'request_size_out': {'average': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0'], [1527161452.257, '0'], [1527161467.257, '0'], [1527161482.257, '0'], [1527161497.257, '0'], [1527161512.257, '0'], [1527161527.257, '0'], [1527161542.257, '0'], [1527161557.257, '0'], [1527161572.257, '0'], [1527161587.257, '0'], [1527161602.257, '0'], [1527161617.257, '0'], [1527161632.257, '0'], [1527161647.257, '0'], [1527161662.257, '0'], [1527161677.257, '0'], [1527161692.257, '0'], [1527161707.257, '0'], [1527161722.257, '0'], [1527161737.257, '0'], [1527161752.257, '0'], [1527161767.257, '0'], [1527161782.257, '0'], [1527161797.257, '0'], [1527161812.257, '0'], [1527161827.257, '0'], [1527161842.257, '0'], [1527161857.257, '0'], [1527161872.257, '0'], [1527161887.257, '0'], [1527161902.257, '0'], [1527161917.257, '0'], [1527161932.257, '0'], [1527161947.257, '0'], [1527161962.257, '0'], [1527161977.257, '0'], [1527161992.257, '0'], [1527162007.257, '0'], [1527162022.257, '0'], [1527162037.257, '0'], [1527162052.257, '0'], [1527162067.257, '0'], [1527162082.257, '0'], [1527162097.257, '0'], [1527162112.257, '0'], [1527162127.257, '0'], [1527162142.257, '0'], [1527162157.257, '0'], [1527162172.257, '0'], [1527162187.257, '0'], [1527162202.257, '0'], [1527162217.257, '0'], [1527162232.257, '0'], [1527162247.257, '0'], [1527162262.257, '0'], [1527162277.257, '0'], [1527162292.257, '0'], [1527162307.257, '0'], [1527162322.257, '0'], [1527162337.257, '0'], [1527162352.257, '0'], [1527162367.257, '0'], [1527162382.257, '0'], [1527162397.257, '0'], [1527162412.257, '0'], [1527162427.257, '0'], [1527162442.257, '0'], [1527162457.257, '0'], [1527162472.257, '0'], [1527162487.257, '0'], [1527162502.257, '0'], [1527162517.257, '0'], [1527162532.257, '0'], [1527162547.257, '0'], [1527162562.257, '0'], [1527162577.257, '0'], [1527162592.257, '0'], [1527162607.257, '0'], [1527162622.257, '0'], [1527162637.257, '0'], [1527162652.257, '0'], [1527162667.257, '0'], [1527162682.257, '0'], [1527162697.257, '0'], [1527162712.257, '0'], [1527162727.257, '0'], [1527162742.257, '0'], [1527162757.257, '0'], [1527162772.257, '0'], [1527162787.257, '0'], [1527162802.257, '0'], [1527162817.257, '0'], [1527162832.257, '0'], [1527162847.257, '0'], [1527162862.257, '0'], [1527162877.257, '0'], [1527162892.257, '0'], [1527162907.257, '0'], [1527162922.257, '0'], [1527162937.257, '0'], [1527162952.257, '0'], [1527162967.257, '0'], [1527162982.257, '0'], [1527162997.257, '0'], [1527163012.257, '0'], [1527163027.257, '0'], [1527163042.257, '0'], [1527163057.257, '0'], [1527163072.257, '0'], [1527163087.257, '0'], [1527163102.257, '0'], [1527163117.257, '0'], [1527163132.257, '0'], [1527163147.257, '0'], [1527163162.257, '0'], [1527163177.257, '0'], [1527163192.257, '0'], [1527163207.257, '0'], [1527163222.257, '0'], [1527163237.257, '0']]}]}, 'median': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.5'], [1527161452.257, '0.5'], [1527161467.257, '0.5'], [1527161482.257, '0.5'], [1527161497.257, '0.5'], [1527161512.257, '0.5'], [1527161527.257, '0.5'], [1527161542.257, '0.5'], [1527161557.257, '0.5'], [1527161572.257, '0.5'], [1527161587.257, '0.5'], [1527161602.257, '0.5'], [1527161617.257, '0.5'], [1527161632.257, '0.5'], [1527161647.257, '0.5'], [1527161662.257, '0.5'], [1527161677.257, '0.5'], [1527161692.257, '0.5'], [1527161707.257, '0.5'], [1527161722.257, '0.5'], [1527161737.257, '0.5'], [1527161752.257, '0.5'], [1527161767.257, '0.5'], [1527161782.257, '0.5'], [1527161797.257, '0.5'], [1527161812.257, '0.5'], [1527161827.257, '0.5'], [1527161842.257, '0.5'], [1527161857.257, '0.5'], [1527161872.257, '0.5'], [1527161887.257, '0.5'], [1527161902.257, '0.5'], [1527161917.257, '0.5'], [1527161932.257, '0.5'], [1527161947.257, '0.5'], [1527161962.257, '0.5'], [1527161977.257, '0.5'], [1527161992.257, '0.5'], [1527162007.257, '0.5'], [1527162022.257, '0.5'], [1527162037.257, '0.5'], [1527162052.257, '0.5'], [1527162067.257, '0.5'], [1527162082.257, '0.5'], [1527162097.257, '0.5'], [1527162112.257, '0.5'], [1527162127.257, '0.5'], [1527162142.257, '0.5'], [1527162157.257, '0.5'], [1527162172.257, '0.5'], [1527162187.257, '0.5'], [1527162202.257, '0.5'], [1527162217.257, '0.5'], [1527162232.257, '0.5'], [1527162247.257, '0.5'], [1527162262.257, '0.5'], [1527162277.257, '0.5'], [1527162292.257, '0.5'], [1527162307.257, '0.5'], [1527162322.257, '0.5'], [1527162337.257, '0.5'], [1527162352.257, '0.5'], [1527162367.257, '0.5'], [1527162382.257, '0.5'], [1527162397.257, '0.5'], [1527162412.257, '0.5'], [1527162427.257, '0.5'], [1527162442.257, '0.5'], [1527162457.257, '0.5'], [1527162472.257, '0.5'], [1527162487.257, '0.5'], [1527162502.257, '0.5'], [1527162517.257, '0.5'], [1527162532.257, '0.5'], [1527162547.257, '0.5'], [1527162562.257, '0.5'], [1527162577.257, '0.5'], [1527162592.257, '0.5'], [1527162607.257, '0.5'], [1527162622.257, '0.5'], [1527162637.257, '0.5'], [1527162652.257, '0.5'], [1527162667.257, '0.5'], [1527162682.257, '0.5'], [1527162697.257, '0.5'], [1527162712.257, '0.5'], [1527162727.257, '0.5'], [1527162742.257, '0.5'], [1527162757.257, '0.5'], [1527162772.257, '0.5'], [1527162787.257, '0.5'], [1527162802.257, '0.5'], [1527162817.257, '0.5'], [1527162832.257, '0.5'], [1527162847.257, '0.5'], [1527162862.257, '0.5'], [1527162877.257, '0.5'], [1527162892.257, '0.5'], [1527162907.257, '0.5'], [1527162922.257, '0.5'], [1527162937.257, '0.5'], [1527162952.257, '0.5'], [1527162967.257, '0.5'], [1527162982.257, '0.5'], [1527162997.257, '0.5'], [1527163012.257, '0.5'], [1527163027.257, '0.5'], [1527163042.257, '0.5'], [1527163057.257, '0.5'], [1527163072.257, '0.5'], [1527163087.257, '0.5'], [1527163102.257, '0.5'], [1527163117.257, '0.5'], [1527163132.257, '0.5'], [1527163147.257, '0.5'], [1527163162.257, '0.5'], [1527163177.257, '0.5'], [1527163192.257, '0.5'], [1527163207.257, '0.5'], [1527163222.257, '0.5'], [1527163237.257, '0.5']]}]}, 'percentile95': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.95'], [1527161452.257, '0.95'], [1527161467.257, '0.95'], [1527161482.257, '0.95'], [1527161497.257, '0.95'], [1527161512.257, '0.95'], [1527161527.257, '0.95'], [1527161542.257, '0.95'], [1527161557.257, '0.95'], [1527161572.257, '0.95'], [1527161587.257, '0.95'], [1527161602.257, '0.95'], [1527161617.257, '0.95'], [1527161632.257, '0.95'], [1527161647.257, '0.95'], [1527161662.257, '0.95'], [1527161677.257, '0.95'], [1527161692.257, '0.95'], [1527161707.257, '0.95'], [1527161722.257, '0.95'], [1527161737.257, '0.95'], [1527161752.257, '0.95'], [1527161767.257, '0.95'], [1527161782.257, '0.95'], [1527161797.257, '0.95'], [1527161812.257, '0.95'], [1527161827.257, '0.95'], [1527161842.257, '0.95'], [1527161857.257, '0.95'], [1527161872.257, '0.95'], [1527161887.257, '0.95'], [1527161902.257, '0.95'], [1527161917.257, '0.95'], [1527161932.257, '0.95'], [1527161947.257, '0.95'], [1527161962.257, '0.95'], [1527161977.257, '0.95'], [1527161992.257, '0.95'], [1527162007.257, '0.95'], [1527162022.257, '0.95'], [1527162037.257, '0.95'], [1527162052.257, '0.95'], [1527162067.257, '0.95'], [1527162082.257, '0.95'], [1527162097.257, '0.95'], [1527162112.257, '0.95'], [1527162127.257, '0.95'], [1527162142.257, '0.95'], [1527162157.257, '0.95'], [1527162172.257, '0.95'], [1527162187.257, '0.95'], [1527162202.257, '0.95'], [1527162217.257, '0.95'], [1527162232.257, '0.95'], [1527162247.257, '0.95'], [1527162262.257, '0.95'], [1527162277.257, '0.95'], [1527162292.257, '0.95'], [1527162307.257, '0.95'], [1527162322.257, '0.95'], [1527162337.257, '0.95'], [1527162352.257, '0.95'], [1527162367.257, '0.95'], [1527162382.257, '0.95'], [1527162397.257, '0.95'], [1527162412.257, '0.95'], [1527162427.257, '0.95'], [1527162442.257, '0.95'], [1527162457.257, '0.95'], [1527162472.257, '0.95'], [1527162487.257, '0.95'], [1527162502.257, '0.95'], [1527162517.257, '0.95'], [1527162532.257, '0.95'], [1527162547.257, '0.95'], [1527162562.257, '0.95'], [1527162577.257, '0.95'], [1527162592.257, '0.95'], [1527162607.257, '0.95'], [1527162622.257, '0.95'], [1527162637.257, '0.95'], [1527162652.257, '0.95'], [1527162667.257, '0.95'], [1527162682.257, '0.95'], [1527162697.257, '0.95'], [1527162712.257, '0.95'], [1527162727.257, '0.95'], [1527162742.257, '0.95'], [1527162757.257, '0.95'], [1527162772.257, '0.95'], [1527162787.257, '0.95'], [1527162802.257, '0.95'], [1527162817.257, '0.95'], [1527162832.257, '0.95'], [1527162847.257, '0.95'], [1527162862.257, '0.95'], [1527162877.257, '0.95'], [1527162892.257, '0.95'], [1527162907.257, '0.95'], [1527162922.257, '0.95'], [1527162937.257, '0.95'], [1527162952.257, '0.95'], [1527162967.257, '0.95'], [1527162982.257, '0.95'], [1527162997.257, '0.95'], [1527163012.257, '0.95'], [1527163027.257, '0.95'], [1527163042.257, '0.95'], [1527163057.257, '0.95'], [1527163072.257, '0.95'], [1527163087.257, '0.95'], [1527163102.257, '0.95'], [1527163117.257, '0.95'], [1527163132.257, '0.95'], [1527163147.257, '0.95'], [1527163162.257, '0.95'], [1527163177.257, '0.95'], [1527163192.257, '0.95'], [1527163207.257, '0.95'], [1527163222.257, '0.95'], [1527163237.257, '0.95']]}]}, 'percentile99': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '0.99'], [1527161452.257, '0.99'], [1527161467.257, '0.99'], [1527161482.257, '0.99'], [1527161497.257, '0.99'], [1527161512.257, '0.99'], [1527161527.257, '0.99'], [1527161542.257, '0.99'], [1527161557.257, '0.99'], [1527161572.257, '0.99'], [1527161587.257, '0.99'], [1527161602.257, '0.99'], [1527161617.257, '0.99'], [1527161632.257, '0.99'], [1527161647.257, '0.99'], [1527161662.257, '0.99'], [1527161677.257, '0.99'], [1527161692.257, '0.99'], [1527161707.257, '0.99'], [1527161722.257, '0.99'], [1527161737.257, '0.99'], [1527161752.257, '0.99'], [1527161767.257, '0.99'], [1527161782.257, '0.99'], [1527161797.257, '0.99'], [1527161812.257, '0.99'], [1527161827.257, '0.99'], [1527161842.257, '0.99'], [1527161857.257, '0.99'], [1527161872.257, '0.99'], [1527161887.257, '0.99'], [1527161902.257, '0.99'], [1527161917.257, '0.99'], [1527161932.257, '0.99'], [1527161947.257, '0.99'], [1527161962.257, '0.99'], [1527161977.257, '0.99'], [1527161992.257, '0.99'], [1527162007.257, '0.99'], [1527162022.257, '0.99'], [1527162037.257, '0.99'], [1527162052.257, '0.99'], [1527162067.257, '0.99'], [1527162082.257, '0.99'], [1527162097.257, '0.99'], [1527162112.257, '0.99'], [1527162127.257, '0.99'], [1527162142.257, '0.99'], [1527162157.257, '0.99'], [1527162172.257, '0.99'], [1527162187.257, '0.99'], [1527162202.257, '0.99'], [1527162217.257, '0.99'], [1527162232.257, '0.99'], [1527162247.257, '0.99'], [1527162262.257, '0.99'], [1527162277.257, '0.99'], [1527162292.257, '0.99'], [1527162307.257, '0.99'], [1527162322.257, '0.99'], [1527162337.257, '0.99'], [1527162352.257, '0.99'], [1527162367.257, '0.99'], [1527162382.257, '0.99'], [1527162397.257, '0.99'], [1527162412.257, '0.99'], [1527162427.257, '0.99'], [1527162442.257, '0.99'], [1527162457.257, '0.99'], [1527162472.257, '0.99'], [1527162487.257, '0.99'], [1527162502.257, '0.99'], [1527162517.257, '0.99'], [1527162532.257, '0.99'], [1527162547.257, '0.99'], [1527162562.257, '0.99'], [1527162577.257, '0.99'], [1527162592.257, '0.99'], [1527162607.257, '0.99'], [1527162622.257, '0.99'], [1527162637.257, '0.99'], [1527162652.257, '0.99'], [1527162667.257, '0.99'], [1527162682.257, '0.99'], [1527162697.257, '0.99'], [1527162712.257, '0.99'], [1527162727.257, '0.99'], [1527162742.257, '0.99'], [1527162757.257, '0.99'], [1527162772.257, '0.99'], [1527162787.257, '0.99'], [1527162802.257, '0.99'], [1527162817.257, '0.99'], [1527162832.257, '0.99'], [1527162847.257, '0.99'], [1527162862.257, '0.99'], [1527162877.257, '0.99'], [1527162892.257, '0.99'], [1527162907.257, '0.99'], [1527162922.257, '0.99'], [1527162937.257, '0.99'], [1527162952.257, '0.99'], [1527162967.257, '0.99'], [1527162982.257, '0.99'], [1527162997.257, '0.99'], [1527163012.257, '0.99'], [1527163027.257, '0.99'], [1527163042.257, '0.99'], [1527163057.257, '0.99'], [1527163072.257, '0.99'], [1527163087.257, '0.99'], [1527163102.257, '0.99'], [1527163117.257, '0.99'], [1527163132.257, '0.99'], [1527163147.257, '0.99'], [1527163162.257, '0.99'], [1527163177.257, '0.99'], [1527163192.257, '0.99'], [1527163207.257, '0.99'], [1527163222.257, '0.99'], [1527163237.257, '0.99']]}]}}, 'response_size_in': {'average': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '1593.901'], [1527161452.257, '1593.861'], [1527161467.257, '1580.565'], [1527161482.257, '1595.48'], [1527161497.257, '1615.163'], [1527161512.257, '1587.653'], [1527161527.257, '1595.52'], [1527161542.257, '1593.901'], [1527161557.257, '1580.605'], [1527161572.257, '1601.343'], [1527161587.257, '1593.901'], [1527161602.257, '1580.435'], [1527161617.257, '1586.966'], [1527161632.257, '1613.446'], [1527161647.257, '1607.015'], [1527161662.257, '1593.901'], [1527161677.257, '1581.06'], [1527161692.257, '1594.667'], [1527161707.257, '1587.653'], [1527161722.257, '1580.605'], [1527161737.257, '1593.143'], [1527161752.257, '1615.084'], [1527161767.257, '1616.035'], [1527161782.257, '1595.48'], [1527161797.257, '1602.643'], [1527161812.257, '1601.025'], [1527161827.257, '1579.702'], [1527161842.257, '1593.182'], [1527161857.257, '1606.564'], [1527161872.257, '1573.378'], [1527161887.257, '1607.837'], [1527161902.257, '1587.772'], [1527161917.257, '1593.653'], [1527161932.257, '1580.985'], [1527161947.257, '1593.901'], [1527161962.257, '1621.371'], [1527161977.257, '1594.706'], [1527161992.257, '1594.667'], [1527162007.257, '1587.426'], [1527162022.257, '1615.163'], [1527162037.257, '1594.706'], [1527162052.257, '1593.941'], [1527162067.257, '1586.966'], [1527162082.257, '1621.351'], [1527162097.257, '1586.926'], [1527162112.257, '1579.775'], [1527162127.257, '1603.216'], [1527162142.257, '1594.746'], [1527162157.257, '1594.706'], [1527162172.257, '1608.708'], [1527162187.257, '1573.418'], [1527162202.257, '1595.48'], [1527162217.257, '1615.124'], [1527162232.257, '1574.005'], [1527162247.257, '1607.075'], [1527162262.257, '1606.975'], [1527162277.257, '1601.66'], [1527162292.257, '1574.065'], [1527162307.257, '1595.52'], [1527162322.257, '1609.439'], [1527162337.257, '1607.51'], [1527162352.257, '1593.941'], [1527162367.257, '1593.901'], [1527162382.257, '1594.498'], [1527162397.257, '1587.653'], [1527162412.257, '1594.746'], [1527162427.257, '1599.796'], [1527162442.257, '1579.134'], [1527162457.257, '1580.426'], [1527162472.257, '1598.947'], [1527162487.257, '1586.167'], [1527162502.257, '1593.941'], [1527162517.257, '1594.667'], [1527162532.257, '1580.605'], [1527162547.257, '1602.603'], [1527162562.257, '1594.667'], [1527162577.257, '1607.759'], [1527162592.257, '1580.565'], [1527162607.257, '1600.044'], [1527162622.257, '1600.044'], [1527162637.257, '1580.415'], [1527162652.257, '1599.966'], [1527162667.257, '1587.653'], [1527162682.257, '1579.905'], [1527162697.257, '1608.668'], [1527162712.257, '1593.103'], [1527162727.257, '1572.678'], [1527162742.257, '1587.01'], [1527162757.257, '1594.706'], [1527162772.257, '1567.1'], [1527162787.257, '1594.746'], [1527162802.257, '1587.446'], [1527162817.257, '1594.746'], [1527162832.257, '1601.025'], [1527162847.257, '1600.228'], [1527162862.257, '1593.389'], [1527162877.257, '1600.149'], [1527162892.257, '1587.502'], [1527162907.257, '1601.402'], [1527162922.257, '1593.941'], [1527162937.257, '1589'], [1527162952.257, '1593.941'], [1527162967.257, '1608.668'], [1527162982.257, '1593.182'], [1527162997.257, '1606.405'], [1527163012.257, '1580.605'], [1527163027.257, '1593.941'], [1527163042.257, '1615.124'], [1527163057.257, '1601.79'], [1527163072.257, '1593.901'], [1527163087.257, '1593.182'], [1527163102.257, '1600.149'], [1527163117.257, '1607.765'], [1527163132.257, '1600.109'], [1527163147.257, '1572.639'], [1527163162.257, '1579.955'], [1527163177.257, '1593.901'], [1527163192.257, '1615.163'], [1527163207.257, '1595.52'], [1527163222.257, '1608.708'], [1527163237.257, '1595.52']]}]}, 'median': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '623.636'], [1527161452.257, '623.636'], [1527161467.257, '623.636'], [1527161482.257, '631.818'], [1527161497.257, '631.818'], [1527161512.257, '624.312'], [1527161527.257, '631.818'], [1527161542.257, '623.636'], [1527161557.257, '623.636'], [1527161572.257, '624.312'], [1527161587.257, '623.636'], [1527161602.257, '620.183'], [1527161617.257, '622.973'], [1527161632.257, '623.636'], [1527161647.257, '623.636'], [1527161662.257, '623.636'], [1527161677.257, '624.312'], [1527161692.257, '627.727'], [1527161707.257, '624.312'], [1527161722.257, '623.636'], [1527161737.257, '619.545'], [1527161752.257, '631.818'], [1527161767.257, '635.909'], [1527161782.257, '631.818'], [1527161797.257, '632.569'], [1527161812.257, '624.312'], [1527161827.257, '614.865'], [1527161842.257, '619.545'], [1527161857.257, '623.636'], [1527161872.257, '619.545'], [1527161887.257, '627.727'], [1527161902.257, '627.027'], [1527161917.257, '620.183'], [1527161932.257, '623.636'], [1527161947.257, '623.636'], [1527161962.257, '628.44'], [1527161977.257, '627.727'], [1527161992.257, '627.727'], [1527162007.257, '623.636'], [1527162022.257, '631.818'], [1527162037.257, '627.727'], [1527162052.257, '623.636'], [1527162067.257, '622.973'], [1527162082.257, '628.44'], [1527162097.257, '622.973'], [1527162112.257, '618.919'], [1527162127.257, '635.909'], [1527162142.257, '627.727'], [1527162157.257, '627.727'], [1527162172.257, '631.818'], [1527162187.257, '619.545'], [1527162202.257, '631.818'], [1527162217.257, '631.818'], [1527162232.257, '623.636'], [1527162247.257, '625'], [1527162262.257, '623.636'], [1527162277.257, '631.081'], [1527162292.257, '623.636'], [1527162307.257, '631.818'], [1527162322.257, '636.697'], [1527162337.257, '623.636'], [1527162352.257, '623.636'], [1527162367.257, '623.636'], [1527162382.257, '626.339'], [1527162397.257, '624.312'], [1527162412.257, '627.727'], [1527162427.257, '618.919'], [1527162442.257, '615.455'], [1527162457.257, '618.919'], [1527162472.257, '614.865'], [1527162487.257, '618.919'], [1527162502.257, '623.636'], [1527162517.257, '627.727'], [1527162532.257, '623.636'], [1527162547.257, '632.569'], [1527162562.257, '627.727'], [1527162577.257, '627.727'], [1527162592.257, '623.636'], [1527162607.257, '622.973'], [1527162622.257, '622.973'], [1527162637.257, '620.183'], [1527162652.257, '622.973'], [1527162667.257, '624.312'], [1527162682.257, '619.545'], [1527162697.257, '631.818'], [1527162712.257, '619.545'], [1527162727.257, '615.455'], [1527162742.257, '623.636'], [1527162757.257, '627.727'], [1527162772.257, '622.973'], [1527162787.257, '627.727'], [1527162802.257, '623.636'], [1527162817.257, '627.727'], [1527162832.257, '624.312'], [1527162847.257, '620.183'], [1527162862.257, '622.973'], [1527162877.257, '620.183'], [1527162892.257, '622.973'], [1527162907.257, '627.027'], [1527162922.257, '623.636'], [1527162937.257, '631.818'], [1527162952.257, '623.636'], [1527162967.257, '631.818'], [1527162982.257, '619.545'], [1527162997.257, '622.973'], [1527163012.257, '623.636'], [1527163027.257, '623.636'], [1527163042.257, '631.818'], [1527163057.257, '628.44'], [1527163072.257, '623.636'], [1527163087.257, '619.545'], [1527163102.257, '620.183'], [1527163117.257, '628.44'], [1527163132.257, '620.183'], [1527163147.257, '615.455'], [1527163162.257, '620.183'], [1527163177.257, '623.636'], [1527163192.257, '631.818'], [1527163207.257, '631.818'], [1527163222.257, '631.818'], [1527163237.257, '631.818']]}]}, 'percentile95': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '8347.273'], [1527161452.257, '8347.273'], [1527161467.257, '8333.333'], [1527161482.257, '8363.636'], [1527161497.257, '8376.786'], [1527161512.257, '8341.667'], [1527161527.257, '8363.636'], [1527161542.257, '8347.273'], [1527161557.257, '8333.333'], [1527161572.257, '8355.455'], [1527161587.257, '8347.273'], [1527161602.257, '8333.333'], [1527161617.257, '8339.091'], [1527161632.257, '8360.714'], [1527161647.257, '8360.714'], [1527161662.257, '8347.273'], [1527161677.257, '8341.667'], [1527161692.257, '8355.455'], [1527161707.257, '8341.667'], [1527161722.257, '8333.333'], [1527161737.257, '8339.091'], [1527161752.257, '8376.786'], [1527161767.257, '8384.821'], [1527161782.257, '8363.636'], [1527161797.257, '8371.818'], [1527161812.257, '8355.455'], [1527161827.257, '8322.727'], [1527161842.257, '8339.091'], [1527161857.257, '8360.714'], [1527161872.257, '8325'], [1527161887.257, '8368.75'], [1527161902.257, '8347.273'], [1527161917.257, '8347.273'], [1527161932.257, '8333.333'], [1527161947.257, '8347.273'], [1527161962.257, '8376.786'], [1527161977.257, '8355.455'], [1527161992.257, '8355.455'], [1527162007.257, '8347.273'], [1527162022.257, '8376.786'], [1527162037.257, '8355.455'], [1527162052.257, '8347.273'], [1527162067.257, '8339.091'], [1527162082.257, '8376.786'], [1527162097.257, '8339.091'], [1527162112.257, '8330.909'], [1527162127.257, '8371.818'], [1527162142.257, '8355.455'], [1527162157.257, '8355.455'], [1527162172.257, '8376.786'], [1527162187.257, '8325'], [1527162202.257, '8363.636'], [1527162217.257, '8376.786'], [1527162232.257, '8333.333'], [1527162247.257, '8363.636'], [1527162262.257, '8360.714'], [1527162277.257, '8368.75'], [1527162292.257, '8333.333'], [1527162307.257, '8363.636'], [1527162322.257, '8380'], [1527162337.257, '8360.714'], [1527162352.257, '8347.273'], [1527162367.257, '8347.273'], [1527162382.257, '8352.679'], [1527162397.257, '8341.667'], [1527162412.257, '8355.455'], [1527162427.257, '8344.643'], [1527162442.257, '8316.667'], [1527162457.257, '8330.909'], [1527162472.257, '8336.607'], [1527162487.257, '8330.909'], [1527162502.257, '8347.273'], [1527162517.257, '8355.455'], [1527162532.257, '8333.333'], [1527162547.257, '8371.818'], [1527162562.257, '8355.455'], [1527162577.257, '8368.75'], [1527162592.257, '8333.333'], [1527162607.257, '8352.679'], [1527162622.257, '8352.679'], [1527162637.257, '8333.333'], [1527162652.257, '8352.679'], [1527162667.257, '8341.667'], [1527162682.257, '8325'], [1527162697.257, '8376.786'], [1527162712.257, '8339.091'], [1527162727.257, '8316.667'], [1527162742.257, '8347.273'], [1527162757.257, '8355.455'], [1527162772.257, '8325'], [1527162787.257, '8355.455'], [1527162802.257, '8347.273'], [1527162817.257, '8355.455'], [1527162832.257, '8355.455'], [1527162847.257, '8347.273'], [1527162862.257, '8339.091'], [1527162877.257, '8347.273'], [1527162892.257, '8339.091'], [1527162907.257, '8360.714'], [1527162922.257, '8347.273'], [1527162937.257, '8363.636'], [1527162952.257, '8347.273'], [1527162967.257, '8376.786'], [1527162982.257, '8339.091'], [1527162997.257, '8352.679'], [1527163012.257, '8333.333'], [1527163027.257, '8347.273'], [1527163042.257, '8376.786'], [1527163057.257, '8363.636'], [1527163072.257, '8347.273'], [1527163087.257, '8339.091'], [1527163102.257, '8347.273'], [1527163117.257, '8363.636'], [1527163132.257, '8347.273'], [1527163147.257, '8316.667'], [1527163162.257, '8333.333'], [1527163177.257, '8347.273'], [1527163192.257, '8376.786'], [1527163207.257, '8363.636'], [1527163222.257, '8376.786'], [1527163237.257, '8363.636']]}]}, 'percentile99': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '9669.455'], [1527161452.257, '9669.455'], [1527161467.257, '9666.667'], [1527161482.257, '9672.727'], [1527161497.257, '9675.357'], [1527161512.257, '9668.333'], [1527161527.257, '9672.727'], [1527161542.257, '9669.455'], [1527161557.257, '9666.667'], [1527161572.257, '9671.091'], [1527161587.257, '9669.455'], [1527161602.257, '9666.667'], [1527161617.257, '9667.818'], [1527161632.257, '9672.143'], [1527161647.257, '9672.143'], [1527161662.257, '9669.455'], [1527161677.257, '9668.333'], [1527161692.257, '9671.091'], [1527161707.257, '9668.333'], [1527161722.257, '9666.667'], [1527161737.257, '9667.818'], [1527161752.257, '9675.357'], [1527161767.257, '9676.964'], [1527161782.257, '9672.727'], [1527161797.257, '9674.364'], [1527161812.257, '9671.091'], [1527161827.257, '9664.545'], [1527161842.257, '9667.818'], [1527161857.257, '9672.143'], [1527161872.257, '9665'], [1527161887.257, '9673.75'], [1527161902.257, '9669.455'], [1527161917.257, '9669.455'], [1527161932.257, '9666.667'], [1527161947.257, '9669.455'], [1527161962.257, '9675.357'], [1527161977.257, '9671.091'], [1527161992.257, '9671.091'], [1527162007.257, '9669.455'], [1527162022.257, '9675.357'], [1527162037.257, '9671.091'], [1527162052.257, '9669.455'], [1527162067.257, '9667.818'], [1527162082.257, '9675.357'], [1527162097.257, '9667.818'], [1527162112.257, '9666.182'], [1527162127.257, '9674.364'], [1527162142.257, '9671.091'], [1527162157.257, '9671.091'], [1527162172.257, '9675.357'], [1527162187.257, '9665'], [1527162202.257, '9672.727'], [1527162217.257, '9675.357'], [1527162232.257, '9666.667'], [1527162247.257, '9672.727'], [1527162262.257, '9672.143'], [1527162277.257, '9673.75'], [1527162292.257, '9666.667'], [1527162307.257, '9672.727'], [1527162322.257, '9676'], [1527162337.257, '9672.143'], [1527162352.257, '9669.455'], [1527162367.257, '9669.455'], [1527162382.257, '9670.536'], [1527162397.257, '9668.333'], [1527162412.257, '9671.091'], [1527162427.257, '9668.929'], [1527162442.257, '9663.333'], [1527162457.257, '9666.182'], [1527162472.257, '9667.321'], [1527162487.257, '9666.182'], [1527162502.257, '9669.455'], [1527162517.257, '9671.091'], [1527162532.257, '9666.667'], [1527162547.257, '9674.364'], [1527162562.257, '9671.091'], [1527162577.257, '9673.75'], [1527162592.257, '9666.667'], [1527162607.257, '9670.536'], [1527162622.257, '9670.536'], [1527162637.257, '9666.667'], [1527162652.257, '9670.536'], [1527162667.257, '9668.333'], [1527162682.257, '9665'], [1527162697.257, '9675.357'], [1527162712.257, '9667.818'], [1527162727.257, '9663.333'], [1527162742.257, '9669.455'], [1527162757.257, '9671.091'], [1527162772.257, '9665'], [1527162787.257, '9671.091'], [1527162802.257, '9669.455'], [1527162817.257, '9671.091'], [1527162832.257, '9671.091'], [1527162847.257, '9669.455'], [1527162862.257, '9667.818'], [1527162877.257, '9669.455'], [1527162892.257, '9667.818'], [1527162907.257, '9672.143'], [1527162922.257, '9669.455'], [1527162937.257, '9672.727'], [1527162952.257, '9669.455'], [1527162967.257, '9675.357'], [1527162982.257, '9667.818'], [1527162997.257, '9670.536'], [1527163012.257, '9666.667'], [1527163027.257, '9669.455'], [1527163042.257, '9675.357'], [1527163057.257, '9672.727'], [1527163072.257, '9669.455'], [1527163087.257, '9667.818'], [1527163102.257, '9669.455'], [1527163117.257, '9672.727'], [1527163132.257, '9669.455'], [1527163147.257, '9663.333'], [1527163162.257, '9666.667'], [1527163177.257, '9669.455'], [1527163192.257, '9675.357'], [1527163207.257, '9672.727'], [1527163222.257, '9675.357'], [1527163237.257, '9672.727']]}]}}, 'response_size_out': {'average': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '209.68'], [1527161452.257, '209.653'], [1527161467.257, '210.212'], [1527161482.257, '210.779'], [1527161497.257, '210.267'], [1527161512.257, '210.462'], [1527161527.257, '210.807'], [1527161542.257, '209.68'], [1527161557.257, '210.24'], [1527161572.257, '210.445'], [1527161587.257, '209.68'], [1527161602.257, '209.952'], [1527161617.257, '209.493'], [1527161632.257, '209.209'], [1527161647.257, '209.182'], [1527161662.257, '209.68'], [1527161677.257, '210.434'], [1527161692.257, '210.212'], [1527161707.257, '210.462'], [1527161722.257, '210.24'], [1527161737.257, '209.155'], [1527161752.257, '210.212'], [1527161767.257, '210.807'], [1527161782.257, '210.779'], [1527161797.257, '211.035'], [1527161812.257, '209.952'], [1527161827.257, '209.213'], [1527161842.257, '209.182'], [1527161857.257, '208.588'], [1527161872.257, '209.68'], [1527161887.257, '209.707'], [1527161902.257, '210.075'], [1527161917.257, '209.34'], [1527161932.257, '210.788'], [1527161947.257, '209.68'], [1527161962.257, '209.925'], [1527161977.257, '210.24'], [1527161992.257, '210.212'], [1527162007.257, '209.68'], [1527162022.257, '210.267'], [1527162037.257, '210.24'], [1527162052.257, '209.707'], [1527162067.257, '209.493'], [1527162082.257, '209.897'], [1527162097.257, '209.466'], [1527162112.257, '208.919'], [1527162127.257, '211.882'], [1527162142.257, '210.267'], [1527162157.257, '210.24'], [1527162172.257, '210.267'], [1527162187.257, '209.707'], [1527162202.257, '210.779'], [1527162217.257, '210.24'], [1527162232.257, '210.185'], [1527162247.257, '208.759'], [1527162262.257, '209.155'], [1527162277.257, '210.048'], [1527162292.257, '210.24'], [1527162307.257, '210.807'], [1527162322.257, '210.741'], [1527162337.257, '209.919'], [1527162352.257, '209.707'], [1527162367.257, '209.68'], [1527162382.257, '210.094'], [1527162397.257, '210.462'], [1527162412.257, '210.267'], [1527162427.257, '209.213'], [1527162442.257, '209.128'], [1527162457.257, '209.758'], [1527162472.257, '208.649'], [1527162487.257, '208.919'], [1527162502.257, '209.707'], [1527162517.257, '210.212'], [1527162532.257, '210.24'], [1527162547.257, '211.007'], [1527162562.257, '210.212'], [1527162577.257, '209.653'], [1527162592.257, '210.212'], [1527162607.257, '208.973'], [1527162622.257, '208.973'], [1527162637.257, '209.952'], [1527162652.257, '208.919'], [1527162667.257, '210.462'], [1527162682.257, '209.707'], [1527162697.257, '210.24'], [1527162712.257, '209.128'], [1527162727.257, '209.128'], [1527162742.257, '209.109'], [1527162757.257, '210.24'], [1527162772.257, '209.993'], [1527162787.257, '210.267'], [1527162802.257, '209.68'], [1527162817.257, '210.267'], [1527162832.257, '209.952'], [1527162847.257, '209.422'], [1527162862.257, '209.493'], [1527162877.257, '209.367'], [1527162892.257, '210.257'], [1527162907.257, '210.284'], [1527162922.257, '209.707'], [1527162937.257, '210.807'], [1527162952.257, '209.707'], [1527162967.257, '210.24'], [1527162982.257, '209.182'], [1527162997.257, '208.973'], [1527163012.257, '210.24'], [1527163027.257, '209.707'], [1527163042.257, '210.24'], [1527163057.257, '210.462'], [1527163072.257, '209.68'], [1527163087.257, '209.182'], [1527163102.257, '209.367'], [1527163117.257, '209.683'], [1527163132.257, '209.34'], [1527163147.257, '209.101'], [1527163162.257, '209.349'], [1527163177.257, '209.68'], [1527163192.257, '210.267'], [1527163207.257, '210.807'], [1527163222.257, '210.267'], [1527163237.257, '210.807']]}]}, 'median': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '398.636'], [1527161452.257, '398.636'], [1527161467.257, '402.727'], [1527161482.257, '406.818'], [1527161497.257, '402.727'], [1527161512.257, '401.376'], [1527161527.257, '406.818'], [1527161542.257, '398.636'], [1527161557.257, '402.727'], [1527161572.257, '397.248'], [1527161587.257, '398.636'], [1527161602.257, '397.248'], [1527161617.257, '400'], [1527161632.257, '394.545'], [1527161647.257, '394.545'], [1527161662.257, '398.636'], [1527161677.257, '401.376'], [1527161692.257, '402.727'], [1527161707.257, '401.376'], [1527161722.257, '402.727'], [1527161737.257, '394.545'], [1527161752.257, '402.727'], [1527161767.257, '406.818'], [1527161782.257, '406.818'], [1527161797.257, '405.505'], [1527161812.257, '397.248'], [1527161827.257, '391.892'], [1527161842.257, '394.545'], [1527161857.257, '394.545'], [1527161872.257, '398.636'], [1527161887.257, '398.636'], [1527161902.257, '404.054'], [1527161917.257, '393.119'], [1527161932.257, '402.727'], [1527161947.257, '398.636'], [1527161962.257, '397.248'], [1527161977.257, '402.727'], [1527161992.257, '402.727'], [1527162007.257, '398.636'], [1527162022.257, '402.727'], [1527162037.257, '402.727'], [1527162052.257, '398.636'], [1527162067.257, '400'], [1527162082.257, '397.248'], [1527162097.257, '400'], [1527162112.257, '395.946'], [1527162127.257, '410.909'], [1527162142.257, '402.727'], [1527162157.257, '402.727'], [1527162172.257, '402.727'], [1527162187.257, '398.636'], [1527162202.257, '406.818'], [1527162217.257, '402.727'], [1527162232.257, '402.727'], [1527162247.257, '395.833'], [1527162262.257, '394.545'], [1527162277.257, '404.054'], [1527162292.257, '402.727'], [1527162307.257, '406.818'], [1527162322.257, '409.633'], [1527162337.257, '394.545'], [1527162352.257, '398.636'], [1527162367.257, '398.636'], [1527162382.257, '401.339'], [1527162397.257, '401.376'], [1527162412.257, '402.727'], [1527162427.257, '391.892'], [1527162442.257, '394.545'], [1527162457.257, '395.946'], [1527162472.257, '387.838'], [1527162487.257, '395.946'], [1527162502.257, '398.636'], [1527162517.257, '402.727'], [1527162532.257, '402.727'], [1527162547.257, '405.505'], [1527162562.257, '402.727'], [1527162577.257, '398.636'], [1527162592.257, '402.727'], [1527162607.257, '395.946'], [1527162622.257, '395.946'], [1527162637.257, '397.248'], [1527162652.257, '395.946'], [1527162667.257, '401.376'], [1527162682.257, '398.636'], [1527162697.257, '402.727'], [1527162712.257, '394.545'], [1527162727.257, '394.545'], [1527162742.257, '398.636'], [1527162757.257, '402.727'], [1527162772.257, '404.054'], [1527162787.257, '402.727'], [1527162802.257, '398.636'], [1527162817.257, '402.727'], [1527162832.257, '397.248'], [1527162847.257, '393.119'], [1527162862.257, '400'], [1527162877.257, '393.119'], [1527162892.257, '400'], [1527162907.257, '400'], [1527162922.257, '398.636'], [1527162937.257, '406.818'], [1527162952.257, '398.636'], [1527162967.257, '402.727'], [1527162982.257, '394.545'], [1527162997.257, '395.946'], [1527163012.257, '402.727'], [1527163027.257, '398.636'], [1527163042.257, '402.727'], [1527163057.257, '401.376'], [1527163072.257, '398.636'], [1527163087.257, '394.545'], [1527163102.257, '393.119'], [1527163117.257, '401.376'], [1527163132.257, '393.119'], [1527163147.257, '394.545'], [1527163162.257, '397.248'], [1527163177.257, '398.636'], [1527163192.257, '402.727'], [1527163207.257, '406.818'], [1527163222.257, '402.727'], [1527163237.257, '406.818']]}]}, 'percentile95': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '939.864'], [1527161452.257, '939.864'], [1527161467.257, '940.273'], [1527161482.257, '940.682'], [1527161497.257, '940.273'], [1527161512.257, '940.138'], [1527161527.257, '940.682'], [1527161542.257, '939.864'], [1527161557.257, '940.273'], [1527161572.257, '939.725'], [1527161587.257, '939.864'], [1527161602.257, '939.725'], [1527161617.257, '940'], [1527161632.257, '939.455'], [1527161647.257, '939.455'], [1527161662.257, '939.864'], [1527161677.257, '940.138'], [1527161692.257, '940.273'], [1527161707.257, '940.138'], [1527161722.257, '940.273'], [1527161737.257, '939.455'], [1527161752.257, '940.273'], [1527161767.257, '940.682'], [1527161782.257, '940.682'], [1527161797.257, '940.55'], [1527161812.257, '939.725'], [1527161827.257, '939.189'], [1527161842.257, '939.455'], [1527161857.257, '939.455'], [1527161872.257, '939.864'], [1527161887.257, '939.864'], [1527161902.257, '940.405'], [1527161917.257, '939.312'], [1527161932.257, '940.273'], [1527161947.257, '939.864'], [1527161962.257, '939.725'], [1527161977.257, '940.273'], [1527161992.257, '940.273'], [1527162007.257, '939.864'], [1527162022.257, '940.273'], [1527162037.257, '940.273'], [1527162052.257, '939.864'], [1527162067.257, '940'], [1527162082.257, '939.725'], [1527162097.257, '940'], [1527162112.257, '939.595'], [1527162127.257, '941.091'], [1527162142.257, '940.273'], [1527162157.257, '940.273'], [1527162172.257, '940.273'], [1527162187.257, '939.864'], [1527162202.257, '940.682'], [1527162217.257, '940.273'], [1527162232.257, '940.273'], [1527162247.257, '939.583'], [1527162262.257, '939.455'], [1527162277.257, '940.405'], [1527162292.257, '940.273'], [1527162307.257, '940.682'], [1527162322.257, '940.963'], [1527162337.257, '939.455'], [1527162352.257, '939.864'], [1527162367.257, '939.864'], [1527162382.257, '940.134'], [1527162397.257, '940.138'], [1527162412.257, '940.273'], [1527162427.257, '939.189'], [1527162442.257, '939.455'], [1527162457.257, '939.595'], [1527162472.257, '938.784'], [1527162487.257, '939.595'], [1527162502.257, '939.864'], [1527162517.257, '940.273'], [1527162532.257, '940.273'], [1527162547.257, '940.55'], [1527162562.257, '940.273'], [1527162577.257, '939.864'], [1527162592.257, '940.273'], [1527162607.257, '939.595'], [1527162622.257, '939.595'], [1527162637.257, '939.725'], [1527162652.257, '939.595'], [1527162667.257, '940.138'], [1527162682.257, '939.864'], [1527162697.257, '940.273'], [1527162712.257, '939.455'], [1527162727.257, '939.455'], [1527162742.257, '939.864'], [1527162757.257, '940.273'], [1527162772.257, '940.405'], [1527162787.257, '940.273'], [1527162802.257, '939.864'], [1527162817.257, '940.273'], [1527162832.257, '939.725'], [1527162847.257, '939.312'], [1527162862.257, '940'], [1527162877.257, '939.312'], [1527162892.257, '940'], [1527162907.257, '940'], [1527162922.257, '939.864'], [1527162937.257, '940.682'], [1527162952.257, '939.864'], [1527162967.257, '940.273'], [1527162982.257, '939.455'], [1527162997.257, '939.595'], [1527163012.257, '940.273'], [1527163027.257, '939.864'], [1527163042.257, '940.273'], [1527163057.257, '940.138'], [1527163072.257, '939.864'], [1527163087.257, '939.455'], [1527163102.257, '939.312'], [1527163117.257, '940.138'], [1527163132.257, '939.312'], [1527163147.257, '939.455'], [1527163162.257, '939.725'], [1527163177.257, '939.864'], [1527163192.257, '940.273'], [1527163207.257, '940.682'], [1527163222.257, '940.273'], [1527163237.257, '940.682']]}]}, 'percentile99': {'matrix': [{'metric': {}, 'values': [[1527161437.257, '987.973'], [1527161452.257, '987.973'], [1527161467.257, '988.055'], [1527161482.257, '988.136'], [1527161497.257, '988.055'], [1527161512.257, '988.028'], [1527161527.257, '988.136'], [1527161542.257, '987.973'], [1527161557.257, '988.055'], [1527161572.257, '987.945'], [1527161587.257, '987.973'], [1527161602.257, '987.945'], [1527161617.257, '988'], [1527161632.257, '987.891'], [1527161647.257, '987.891'], [1527161662.257, '987.973'], [1527161677.257, '988.028'], [1527161692.257, '988.055'], [1527161707.257, '988.028'], [1527161722.257, '988.055'], [1527161737.257, '987.891'], [1527161752.257, '988.055'], [1527161767.257, '988.136'], [1527161782.257, '988.136'], [1527161797.257, '988.11'], [1527161812.257, '987.945'], [1527161827.257, '987.838'], [1527161842.257, '987.891'], [1527161857.257, '987.891'], [1527161872.257, '987.973'], [1527161887.257, '987.973'], [1527161902.257, '988.081'], [1527161917.257, '987.862'], [1527161932.257, '988.055'], [1527161947.257, '987.973'], [1527161962.257, '987.945'], [1527161977.257, '988.055'], [1527161992.257, '988.055'], [1527162007.257, '987.973'], [1527162022.257, '988.055'], [1527162037.257, '988.055'], [1527162052.257, '987.973'], [1527162067.257, '988'], [1527162082.257, '987.945'], [1527162097.257, '988'], [1527162112.257, '987.919'], [1527162127.257, '988.218'], [1527162142.257, '988.055'], [1527162157.257, '988.055'], [1527162172.257, '988.055'], [1527162187.257, '987.973'], [1527162202.257, '988.136'], [1527162217.257, '988.055'], [1527162232.257, '988.055'], [1527162247.257, '987.917'], [1527162262.257, '987.891'], [1527162277.257, '988.081'], [1527162292.257, '988.055'], [1527162307.257, '988.136'], [1527162322.257, '988.193'], [1527162337.257, '987.891'], [1527162352.257, '987.973'], [1527162367.257, '987.973'], [1527162382.257, '988.027'], [1527162397.257, '988.028'], [1527162412.257, '988.055'], [1527162427.257, '987.838'], [1527162442.257, '987.891'], [1527162457.257, '987.919'], [1527162472.257, '987.757'], [1527162487.257, '987.919'], [1527162502.257, '987.973'], [1527162517.257, '988.055'], [1527162532.257, '988.055'], [1527162547.257, '988.11'], [1527162562.257, '988.055'], [1527162577.257, '987.973'], [1527162592.257, '988.055'], [1527162607.257, '987.919'], [1527162622.257, '987.919'], [1527162637.257, '987.945'], [1527162652.257, '987.919'], [1527162667.257, '988.028'], [1527162682.257, '987.973'], [1527162697.257, '988.055'], [1527162712.257, '987.891'], [1527162727.257, '987.891'], [1527162742.257, '987.973'], [1527162757.257, '988.055'], [1527162772.257, '988.081'], [1527162787.257, '988.055'], [1527162802.257, '987.973'], [1527162817.257, '988.055'], [1527162832.257, '987.945'], [1527162847.257, '987.862'], [1527162862.257, '988'], [1527162877.257, '987.862'], [1527162892.257, '988'], [1527162907.257, '988'], [1527162922.257, '987.973'], [1527162937.257, '988.136'], [1527162952.257, '987.973'], [1527162967.257, '988.055'], [1527162982.257, '987.891'], [1527162997.257, '987.919'], [1527163012.257, '988.055'], [1527163027.257, '987.973'], [1527163042.257, '988.055'], [1527163057.257, '988.028'], [1527163072.257, '987.973'], [1527163087.257, '987.891'], [1527163102.257, '987.862'], [1527163117.257, '988.028'], [1527163132.257, '987.862'], [1527163147.257, '987.891'], [1527163162.257, '987.945'], [1527163177.257, '987.973'], [1527163192.257, '988.055'], [1527163207.257, '988.136'], [1527163222.257, '988.055'], [1527163237.257, '988.136']]}]}}}}

```

## Istio Config List

- This method will return a list of istio configurations for specific namespace
- Required Parameter (`namespace`)

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.istio_config_list("bookinfo")
{'namespace': {'name': 'bookinfo'}, 'route_rules': [], 'destination_policies': [], 'virtual_services': [], 'destination_rules': [], 'rules': []}
```

- For istio system it will return istio rules list as well

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.istio_config_list("istio-system")
>>> {'namespace': {'name': 'istio-system'}, 'route_rules': [], 'destination_policies': [], 'virtual_services': [], 'destination_rules': [], 'rules': [{'name': 'kubeattrgenrulerule', 'match': None, 'actions': [{'handler': 'handler.kubernetesenv', 'instances': ['attributes.kubernetes']}]}, {'name': 'promhttp', 'match': 'context.protocol == "http"', 'actions': [{'handler': 'handler.prometheus', 'instances': ['requestcount.metric', 'requestduration.metric', 'requestsize.metric', 'responsesize.metric']}]}, {'name': 'promtcp', 'match': 'context.protocol == "tcp"', 'actions': [{'handler': 'handler.prometheus', 'instances': ['tcpbytesent.metric', 'tcpbytereceived.metric']}]}, {'name': 'stdio', 'match': 'true', 'actions': [{'handler': 'handler.stdio', 'instances': ['accesslog.logentry']}]}, {'name': 'tcpkubeattrgenrulerule', 'match': 'context.protocol == "tcp"', 'actions': [{'handler': 'handler.kubernetesenv', 'instances': ['attributes.kubernetes']}]}]}
```

## Istio Config Details

- This method will give a detail for each istio object

- Required Parameter (`namespace`, `object_type`, `object_name`)
```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.istio_config_details("istio-system", "rules", "promtcp")
{'namespace': {'name': 'istio-system'}, 'object_type': 'rules', 'route_rule': None, 'destination_policy': None, 'virtual_service': None, 'destination_rule': None, 'rule': {'name': 'promtcp', 'namespace': {'name': ''}, 'match': 'context.protocol == "tcp"', 'actions': [{'handler': {'name': 'handler', 'adapter': 'prometheus', 'spec': {'metrics': [{'instance_name': 'requestcount.metric.istio-system', 'kind': 'COUNTER', 'label_names': ['source_service', 'source_version', 'destination_service', 'destination_version', 'response_code', 'connection_mtls'], 'name': 'request_count'}, {'buckets': {'explicit_buckets': {'bounds': [0.005, 0.01, 0.025, 0.05, 0.1, 0.25, 0.5, 1, 2.5, 5, 10]}}, 'instance_name': 'requestduration.metric.istio-system', 'kind': 'DISTRIBUTION', 'label_names': ['source_service', 'source_version', 'destination_service', 'destination_version', 'response_code', 'connection_mtls'], 'name': 'request_duration'}, {'buckets': {'exponentialBuckets': {'growthFactor': 10, 'numFiniteBuckets': 8, 'scale': 1}}, 'instance_name': 'requestsize.metric.istio-system', 'kind': 'DISTRIBUTION', 'label_names': ['source_service', 'source_version', 'destination_service', 'destination_version', 'response_code', 'connection_mtls'], 'name': 'request_size'}, {'buckets': {'exponentialBuckets': {'growthFactor': 10, 'numFiniteBuckets': 8, 'scale': 1}}, 'instance_name': 'responsesize.metric.istio-system', 'kind': 'DISTRIBUTION', 'label_names': ['source_service', 'source_version', 'destination_service', 'destination_version', 'response_code', 'connection_mtls'], 'name': 'response_size'}, {'instance_name': 'tcpbytesent.metric.istio-system', 'kind': 'COUNTER', 'label_names': ['source_service', 'source_version', 'destination_service', 'destination_version', 'connection_mtls'], 'name': 'tcp_bytes_sent'}, {'instance_name': 'tcpbytereceived.metric.istio-system', 'kind': 'COUNTER', 'label_names': ['source_service', 'source_version', 'destination_service', 'destination_version', 'connection_mtls'], 'name': 'tcp_bytes_received'}]}}, 'instances': [{'name': 'tcpbytereceived', 'template': 'metric', 'spec': {'dimensions': {'connection_mtls': 'connection.mtls | false', 'destination_service': 'destination.service | "unknown"', 'destination_version': 'destination.labels["version"] | "unknown"', 'source_service': 'source.service | "unknown"', 'source_version': 'source.labels["version"] | "unknown"'}, 'monitored_resource_type': '"UNSPECIFIED"', 'value': 'connection.received.bytes | 0'}}, {'name': 'tcpbytesent', 'template': 'metric', 'spec': {'dimensions': {'connection_mtls': 'connection.mtls | false', 'destination_service': 'destination.service | "unknown"', 'destination_version': 'destination.labels["version"] | "unknown"', 'source_service': 'source.service | "unknown"', 'source_version': 'source.labels["version"] | "unknown"'}, 'monitored_resource_type': '"UNSPECIFIED"', 'value': 'connection.sent.bytes | 0'}}]}]}}
```

## Service List

- This method will return a dictionary with `Namespace` and list of `Service`

- Required Parameter (`namespace`)

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.service_list(namespace="istio-system")
{'namespace': {'name': 'istio-system'}, 'services': [{'name': 'grafana', 'replicas': 1, 'availableReplicas': 1, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}, {'name': 'istio-ingress', 'replicas': 1, 'availableReplicas': 1, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}, {'name': 'istio-mixer', 'replicas': 1, 'availableReplicas': 1, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}, {'name': 'istio-pilot', 'replicas': 1, 'availableReplicas': 1, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}, {'name': 'jaeger-agent', 'replicas': 0, 'availableReplicas': 0, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}, {'name': 'jaeger-collector', 'replicas': 0, 'availableReplicas': 0, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}, {'name': 'jaeger-query', 'replicas': 0, 'availableReplicas': 0, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}, {'name': 'kiali', 'replicas': 1, 'availableReplicas': 1, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}, {'name': 'prometheus', 'replicas': 1, 'availableReplicas': 1, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}, {'name': 'zipkin', 'replicas': 0, 'availableReplicas': 0, 'unavailableReplicas': 0, 'istioSidecar': False, 'requestCount': '0', 'requestErrorCount': '0', 'errorRate': '0'}]}
```


## Service Details


- This method will return a `Service`

- Required Parameter (`namespace`, `service`)


```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.service_details(namespace='istio-system', service="grafana")
{'name': 'grafana', 'type': 'ClusterIP', 'ip': '172.22.213.86', 'ports': [{'name': 'http', 'protocol': 'TCP', 'port': 3000}], 'endpoints': [{'addresses': [{'kind': 'Pod', 'name': 'grafana-274859801-q5ggz', 'ip': '172.20.12.5'}], 'ports': [{'name': 'http', 'protocol': 'TCP', 'port': 3000}]}], 'dependencies': {}, 'deployments': [{'name': 'grafana', 'template_annotations': {'sidecar.istio.io/inject': 'false'}, 'labels': {'app': 'grafana'}, 'created_at': '2018-04-10T12:16:35Z', 'replicas': 1, 'available_replicas': 1, 'unavailable_replicas': 0, 'autoscaler': {'name': '', 'labels': None, 'created_at': '', 'min_replicas': 0, 'max_replicas': 0, 'target_cpu_utilization_percentage': 0, 'current_replicas': 0, 'desired_replicas': 0}}]}
```


## Service Metrics
- This method will return a dictonary of Service metrics

- Required Parameter (`namespace`, `service`)

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.service_metrics(namespace='istio-system', service="grafana")
{'metrics': {'request_count_in': {'matrix': []}, 'request_count_out': {'matrix': []}, 'request_error_count_in': {'matrix': []}, 'request_error_count_out': {'matrix': []}}, 'histograms': {'request_duration_in': {'average': {'matrix': []}, 'median': {'matrix': []}, 'percentile95': {'matrix': []}, 'percentile99': {'matrix': []}}, 'request_duration_out': {'average': {'matrix': []}, 'median': {'matrix': []}, 'percentile95': {'matrix': []}, 'percentile99': {'matrix': []}}, 'request_size_in': {'average': {'matrix': []}, 'median': {'matrix': []}, 'percentile95': {'matrix': []}, 'percentile99': {'matrix': []}}, 'request_size_out': {'average': {'matrix': []}, 'median': {'matrix': []}, 'percentile95': {'matrix': []}, 'percentile99': {'matrix': []}}, 'response_size_in': {'average': {'matrix': []}, 'median': {'matrix': []}, 'percentile95': {'matrix': []}, 'percentile99': {'matrix': []}}, 'response_size_out': {'average': {'matrix': []}, 'median': {'matrix': []}, 'percentile95': {'matrix': []}, 'percentile99': {'matrix': []}}}}
```


## Service Heath

- This method will return a dictonary with `Health`

- Required Parameter (`namespace`, `service`)

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.service_health(namespace='istio-system', service="grafana")
{'healthyReplicas': 1, 'totalReplicas': 1}
```

## Graph Namespace

- This method will return a `Graph`, containing a dictionary with array of `Node` and array of `Edges`
- Required Parameter (`namespace`)
- Additional Parameters that can be included eg: {params={'interval': '7d', offset: '30m'}}

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.graph_namespace(namespace='bookinfo')
{'timestamp': 1527163899, 'elements': {'nodes': [{'data': {'id': 'n2', 'service': 'details.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '0.998'}}, {'data': {'id': 'n1', 'service': 'productpage.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '1.000'}}, {'data': {'id': 'n5', 'service': 'ratings.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '0.667'}}, {'data': {'id': 'n7', 'service': 'reviews.bookinfo.svc.cluster.local', 'isGroup': 'version'}}, {'data': {'id': 'n3', 'parent': 'n7', 'service': 'reviews.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '0.333'}}, {'data': {'id': 'n4', 'parent': 'n7', 'service': 'reviews.bookinfo.svc.cluster.local', 'version': 'v2', 'rate': '0.334'}}, {'data': {'id': 'n6', 'parent': 'n7', 'service': 'reviews.bookinfo.svc.cluster.local', 'version': 'v3', 'rate': '0.333'}}, {'data': {'id': 'n0', 'service': 'unknown', 'version': 'unknown', 'isRoot': 'true'}}], 'edges': [{'data': {'id': 'e0', 'source': 'n0', 'target': 'n1', 'rate': '1.000', 'latency': '0.091'}}, {'data': {'id': 'e1', 'source': 'n1', 'target': 'n2', 'rate': '0.998', 'percentRate': '49.950', 'latency': '0.010'}}, {'data': {'id': 'e2', 'source': 'n1', 'target': 'n3', 'rate': '0.333', 'percentRate': '16.667', 'latency': '0.022'}}, {'data': {'id': 'e3', 'source': 'n1', 'target': 'n4', 'rate': '0.334', 'percentRate': '16.717', 'latency': '0.034'}}, {'data': {'id': 'e5', 'source': 'n1', 'target': 'n6', 'rate': '0.333', 'percentRate': '16.667', 'latency': '0.024'}}, {'data': {'id': 'e4', 'source': 'n4', 'target': 'n5', 'rate': '0.334', 'latency': '0.005'}}, {'data': {'id': 'e6', 'source': 'n6', 'target': 'n5', 'rate': '0.333', 'latency': '0.005'}}]}}
```


### Aditional Parameters
- Additional Parameters can be included on a params dictionary to query a graph namespace
- Available Parameters are `offset` and `interval`


```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.graph_namespace(namespace='bookinfo', params={'interval': '7d'})
{'timestamp': 1527163933, 'elements': {'nodes': [{'data': {'id': 'n2', 'service': 'details.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '0.998'}}, {'data': {'id': 'n1', 'service': 'productpage.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '0.998'}}, {'data': {'id': 'n5', 'service': 'ratings.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '0.666'}}, {'data': {'id': 'n7', 'service': 'reviews.bookinfo.svc.cluster.local', 'isGroup': 'version'}}, {'data': {'id': 'n3', 'parent': 'n7', 'service': 'reviews.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '0.334'}}, {'data': {'id': 'n4', 'parent': 'n7', 'service': 'reviews.bookinfo.svc.cluster.local', 'version': 'v2', 'rate': '0.333'}}, {'data': {'id': 'n6', 'parent': 'n7', 'service': 'reviews.bookinfo.svc.cluster.local', 'version': 'v3', 'rate': '0.333'}}, {'data': {'id': 'n0', 'service': 'unknown', 'version': 'unknown', 'isRoot': 'true'}}], 'edges': [{'data': {'id': 'e0', 'source': 'n0', 'target': 'n1', 'rate': '0.998', 'latency': '0.091'}}, {'data': {'id': 'e1', 'source': 'n1', 'target': 'n2', 'rate': '0.998', 'percentRate': '49.950', 'latency': '0.010'}}, {'data': {'id': 'e2', 'source': 'n1', 'target': 'n3', 'rate': '0.334', 'percentRate': '16.717', 'latency': '0.022'}}, {'data': {'id': 'e3', 'source': 'n1', 'target': 'n4', 'rate': '0.333', 'percentRate': '16.667', 'latency': '0.035'}}, {'data': {'id': 'e5', 'source': 'n1', 'target': 'n6', 'rate': '0.333', 'percentRate': '16.667', 'latency': '0.024'}}, {'data': {'id': 'e4', 'source': 'n4', 'target': 'n5', 'rate': '0.333', 'latency': '0.005'}}, {'data': {'id': 'e6', 'source': 'n6', 'target': 'n5', 'rate': '0.333', 'latency': '0.005'}}]}}
```



## Graph Service

- This method will return a `Graph`, containing a dictionary with array of `Node` and array of `Edges`
- Required Parameter (`namespace`)

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.graph_service(namespace='bookinfo', service='reviews')
{'timestamp': 1527163971, 'elements': {'nodes': [{'data': {'id': 'n0', 'service': 'productpage.bookinfo.svc.cluster.local', 'version': 'v1'}}, {'data': {'id': 'n3', 'service': 'ratings.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '0.665'}}, {'data': {'id': 'n5', 'service': 'reviews.bookinfo.svc.cluster.local', 'isGroup': 'version'}}, {'data': {'id': 'n1', 'parent': 'n5', 'service': 'reviews.bookinfo.svc.cluster.local', 'version': 'v1', 'rate': '0.334'}}, {'data': {'id': 'n2', 'parent': 'n5', 'service': 'reviews.bookinfo.svc.cluster.local', 'version': 'v2', 'rate': '0.331'}}, {'data': {'id': 'n4', 'parent': 'n5', 'service': 'reviews.bookinfo.svc.cluster.local', 'version': 'v3', 'rate': '0.334'}}], 'edges': [{'data': {'id': 'e0', 'source': 'n0', 'target': 'n1', 'rate': '0.334', 'percentRate': '33.433'}}, {'data': {'id': 'e1', 'source': 'n0', 'target': 'n2', 'rate': '0.331', 'percentRate': '33.133'}}, {'data': {'id': 'e3', 'source': 'n0', 'target': 'n4', 'rate': '0.334', 'percentRate': '33.433'}}, {'data': {'id': 'e2', 'source': 'n2', 'target': 'n3', 'rate': '0.331'}}, {'data': {'id': 'e4', 'source': 'n4', 'target': 'n3', 'rate': '0.334'}}]}}
```

### Aditional Parameters
- Additional Parameters can be included on a params dictionary to query a service graph
- Available Parameters are `offset` and `interval`

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.graph_service(namespace='bookinfo', service='reviews', params={'interval': '7d', 'offset': '30m'})
{'elements': {'nodes': [{'data': {'id': 'n0', 'version': 'unknown', 'text': 'e', 'service': 'e.kiali-test-depth.svc.cluster.local'}}, {'data': {'id': 'n1', 'version': 'unknown', 'text': 'f', 'rate': '1.0000', 'service': 'f.kiali-test-depth.svc.cluster.local'}}], 'edges': [{'data': {'id': 'e0', 'source': 'n0', 'target': 'n1', 'text': '1.00', 'color': 'green', 'style': 'solid', 'rate': '1.0000'}}]}}

```

## App List
- This method will return a list of applications for specific namespace
- Required Parameter (`namespace`)

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.app_list(namespace='bookinfo')
{u'applications': [{u'istioSidecar': True, u'name': u'details'},  {u'istioSidecar': True, u'name': u'productpage'},  {u'istioSidecar': True, u'name': u'ratings'},  {u'istioSidecar': True, u'name': u'reviews'}], u'namespace': {u'name': u'bookinfo'}}

```

## App Details
- This method will return details of a specific application
- Required Parameters (`namespace`, `app`)

```python
>>> from kiali import KialiClient
>>> client = KialiClient(host='kiali-url.com')
>>> client.app_details(namespace='bookinfo', app='productpage')
{u'name': u'productpage', u'namespace': {u'name': u'bookinfo'}, u'workloads': [{u'istioSidecar': True,   u'serviceNames': [u'productpage'],   u'workloadName': u'productpage-v1'}]}

```
